from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    # from https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Hungary
    license_formats = (
        '???-###',
    )



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        '{{last_name}} {{company_suffix}}',
        '{{last_name}} {{last_name}} {{company_suffix}}',
        '{{last_name}}',
    )

    company_suffixes = (
        'АД', 'AD',
        'ADSITz', 'АДСИЦ',
        'EAD', 'ЕАД',
        'EOOD', 'ЕООД',
        'ET', 'ET',
        'OOD', 'ООД',
        'KD', 'КД',
        'KDA', 'КДА',
        'SD', 'СД',
    )



from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    # Source: https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Norway
    license_formats = (
        # Classic format
        '?? #####',
    )



from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """en_US word list is drawn from Education First's "1000 Most Common Words in English":
    http://www.ef.edu/english-resources/english-vocabulary/top-1000-words/
    Some words have been removed to make this list appropriate for public testing"""

    word_list = (
        'a',
        'ability',
        'able',
        'about',
        'above',
        'accept',
        'according',
        'account',
        'across',
        'act',
        'action',
        'activity',
        'actually',
        'add',
        'address',
        'administration',
        'admit',
        'adult',
        'affect',
        'after',
        'again',
        'against',
        'age',
        'agency',
        'agent',
        'ago',
        'agree',
        'agreement',
        'ahead',
        'air',
        'all',
        'allow',
        'almost',
        'alone',
        'along',
        'already',
        'also',
        'although',
        'always',
        'American',
        'among',
        'amount',
        'analysis',
        'and',
        'animal',
        'another',
        'answer',
        'any',
        'anyone',
        'anything',
        'appear',
        'apply',
        'approach',
        'area',
        'argue',
        'arm',
        'around',
        'arrive',
        'art',
        'article',
        'artist',
        'as',
        'ask',
        'assume',
        'at',
        'attack',
        'attention',
        'attorney',
        'audience',
        'author',
        'authority',
        'available',
        'avoid',
        'away',
        'baby',
        'back',
        'bad',
        'bag',
        'ball',
        'bank',
        'bar',
        'base',
        'be',
        'beat',
        'beautiful',
        'because',
        'become',
        'bed',
        'before',
        'begin',
        'behavior',
        'behind',
        'believe',
        'benefit',
        'best',
        'better',
        'between',
        'beyond',
        'big',
        'bill',
        'billion',
        'bit',
        'black',
        'blood',
        'blue',
        'board',
        'body',
        'book',
        'born',
        'both',
        'box',
        'boy',
        'break',
        'bring',
        'brother',
        'budget',
        'build',
        'building',
        'business',
        'but',
        'buy',
        'by',
        'call',
        'camera',
        'campaign',
        'can',
        'candidate',
        'capital',
        'car',
        'card',
        'care',
        'career',
        'carry',
        'case',
        'catch',
        'cause',
        'cell',
        'center',
        'central',
        'century',
        'certain',
        'certainly',
        'chair',
        'challenge',
        'chance',
        'change',
        'character',
        'charge',
        'check',
        'child',
        'choice',
        'choose',
        'church',
        'citizen',
        'city',
        'civil',
        'claim',
        'class',
        'clear',
        'clearly',
        'close',
        'coach',
        'cold',
        'collection',
        'college',
        'color',
        'commercial',
        'common',
        'community',
        'company',
        'compare',
        'computer',
        'concern',
        'condition',
        'conference',
        'Congress',
        'consider',
        'consumer',
        'contain',
        'continue',
        'control',
        'cost',
        'could',
        'country',
        'couple',
        'course',
        'court',
        'cover',
        'create',
        'crime',
        'cultural',
        'culture',
        'cup',
        'current',
        'customer',
        'cut',
        'dark',
        'data',
        'daughter',
        'day',
        'deal',
        'debate',
        'decade',
        'decide',
        'decision',
        'deep',
        'defense',
        'degree',
        'Democrat',
        'democratic',
        'describe',
        'design',
        'despite',
        'detail',
        'determine',
        'develop',
        'development',
        'difference',
        'different',
        'difficult',
        'dinner',
        'direction',
        'director',
        'discover',
        'discuss',
        'discussion',
        'do',
        'doctor',
        'dog',
        'door',
        'down',
        'draw',
        'dream',
        'drive',
        'drop',
        'drug',
        'during',
        'each',
        'early',
        'east',
        'easy',
        'eat',
        'economic',
        'economy',
        'edge',
        'education',
        'effect',
        'effort',
        'eight',
        'either',
        'election',
        'else',
        'employee',
        'end',
        'energy',
        'enjoy',
        'enough',
        'enter',
        'entire',
        'environment',
        'environmental',
        'especially',
        'establish',
        'even',
        'evening',
        'event',
        'ever',
        'every',
        'everybody',
        'everyone',
        'everything',
        'evidence',
        'exactly',
        'example',
        'executive',
        'exist',
        'expect',
        'experience',
        'expert',
        'explain',
        'eye',
        'face',
        'fact',
        'factor',
        'fall',
        'family',
        'far',
        'fast',
        'father',
        'fear',
        'federal',
        'feel',
        'feeling',
        'few',
        'field',
        'fight',
        'figure',
        'fill',
        'film',
        'final',
        'finally',
        'financial',
        'find',
        'fine',
        'finish',
        'fire',
        'firm',
        'first',
        'fish',
        'five',
        'floor',
        'fly',
        'focus',
        'follow',
        'food',
        'foot',
        'for',
        'force',
        'foreign',
        'forget',
        'form',
        'former',
        'forward',
        'four',
        'free',
        'friend',
        'from',
        'front',
        'full',
        'fund',
        'future',
        'game',
        'garden',
        'gas',
        'general',
        'generation',
        'get',
        'girl',
        'give',
        'glass',
        'go',
        'goal',
        'good',
        'government',
        'great',
        'green',
        'ground',
        'group',
        'grow',
        'growth',
        'guess',
        'gun',
        'guy',
        'hair',
        'half',
        'hand',
        'happen',
        'happy',
        'hard',
        'have',
        'he',
        'head',
        'health',
        'hear',
        'heart',
        'heavy',
        'help',
        'her',
        'here',
        'herself',
        'high',
        'him',
        'himself',
        'his',
        'history',
        'hit',
        'hold',
        'home',
        'hope',
        'hospital',
        'hot',
        'hotel',
        'hour',
        'house',
        'how',
        'however',
        'huge',
        'human',
        'hundred',
        'husband',
        'I',
        'idea',
        'identify',
        'if',
        'image',
        'imagine',
        'impact',
        'important',
        'improve',
        'in',
        'include',
        'including',
        'increase',
        'indeed',
        'indicate',
        'individual',
        'industry',
        'information',
        'inside',
        'instead',
        'institution',
        'interest',
        'interesting',
        'international',
        'interview',
        'into',
        'investment',
        'involve',
        'issue',
        'it',
        'item',
        'its',
        'itself',
        'job',
        'join',
        'just',
        'keep',
        'key',
        'kid',
        'kind',
        'kitchen',
        'know',
        'knowledge',
        'land',
        'language',
        'large',
        'last',
        'late',
        'later',
        'laugh',
        'law',
        'lawyer',
        'lay',
        'lead',
        'leader',
        'learn',
        'least',
        'leave',
        'left',
        'leg',
        'less',
        'let',
        'letter',
        'level',
        'life',
        'light',
        'like',
        'likely',
        'line',
        'list',
        'listen',
        'little',
        'live',
        'local',
        'long',
        'look',
        'lose',
        'loss',
        'lot',
        'low',
        'machine',
        'magazine',
        'main',
        'maintain',
        'major',
        'majority',
        'make',
        'man',
        'manage',
        'management',
        'manager',
        'many',
        'market',
        'marriage',
        'material',
        'matter',
        'may',
        'maybe',
        'me',
        'mean',
        'measure',
        'media',
        'medical',
        'meet',
        'meeting',
        'member',
        'memory',
        'mention',
        'message',
        'method',
        'middle',
        'might',
        'military',
        'million',
        'mind',
        'minute',
        'miss',
        'mission',
        'model',
        'modern',
        'moment',
        'money',
        'month',
        'more',
        'morning',
        'most',
        'mother',
        'mouth',
        'move',
        'movement',
        'movie',
        'Mr',
        'Mrs',
        'much',
        'music',
        'must',
        'my',
        'myself',
        'name',
        'nation',
        'national',
        'natural',
        'nature',
        'near',
        'nearly',
        'necessary',
        'need',
        'network',
        'never',
        'new',
        'news',
        'newspaper',
        'next',
        'nice',
        'night',
        'no',
        'none',
        'nor',
        'north',
        'not',
        'note',
        'nothing',
        'notice',
        'now',
        'number',
        'occur',
        'of',
        'off',
        'offer',
        'office',
        'officer',
        'official',
        'often',
        'oil',
        'ok',
        'old',
        'on',
        'once',
        'one',
        'only',
        'onto',
        'open',
        'operation',
        'opportunity',
        'option',
        'or',
        'order',
        'organization',
        'other',
        'others',
        'our',
        'out',
        'outside',
        'over',
        'own',
        'owner',
        'page',
        'painting',
        'paper',
        'parent',
        'part',
        'participant',
        'particular',
        'particularly',
        'partner',
        'party',
        'pass',
        'past',
        'pattern',
        'pay',
        'peace',
        'people',
        'per',
        'perform',
        'performance',
        'perhaps',
        'person',
        'personal',
        'phone',
        'physical',
        'pick',
        'picture',
        'piece',
        'place',
        'plan',
        'plant',
        'play',
        'player',
        'PM',
        'point',
        'police',
        'policy',
        'political',
        'politics',
        'poor',
        'popular',
        'population',
        'position',
        'positive',
        'possible',
        'power',
        'practice',
        'prepare',
        'present',
        'president',
        'pressure',
        'pretty',
        'prevent',
        'price',
        'probably',
        'process',
        'produce',
        'product',
        'production',
        'professional',
        'professor',
        'program',
        'project',
        'property',
        'protect',
        'prove',
        'provide',
        'public',
        'pull',
        'purpose',
        'push',
        'put',
        'quality',
        'question',
        'quickly',
        'quite',
        'race',
        'radio',
        'raise',
        'range',
        'rate',
        'rather',
        'reach',
        'read',
        'ready',
        'real',
        'reality',
        'realize',
        'really',
        'reason',
        'receive',
        'recent',
        'recently',
        'recognize',
        'record',
        'red',
        'reduce',
        'reflect',
        'region',
        'relate',
        'relationship',
        'religious',
        'remain',
        'remember',
        'report',
        'represent',
        'Republican',
        'require',
        'research',
        'resource',
        'respond',
        'response',
        'responsibility',
        'rest',
        'result',
        'return',
        'reveal',
        'rich',
        'right',
        'rise',
        'risk',
        'road',
        'rock',
        'role',
        'room',
        'rule',
        'run',
        'safe',
        'same',
        'save',
        'say',
        'scene',
        'school',
        'science',
        'scientist',
        'score',
        'sea',
        'season',
        'seat',
        'second',
        'section',
        'security',
        'see',
        'seek',
        'seem',
        'sell',
        'send',
        'senior',
        'sense',
        'series',
        'serious',
        'serve',
        'service',
        'set',
        'seven',
        'several',
        'shake',
        'share',
        'she',
        'short',
        'should',
        'shoulder',
        'show',
        'side',
        'sign',
        'significant',
        'similar',
        'simple',
        'simply',
        'since',
        'sing',
        'single',
        'sister',
        'sit',
        'site',
        'situation',
        'six',
        'size',
        'skill',
        'skin',
        'small',
        'smile',
        'so',
        'social',
        'society',
        'soldier',
        'some',
        'somebody',
        'someone',
        'something',
        'sometimes',
        'son',
        'song',
        'soon',
        'sort',
        'sound',
        'source',
        'south',
        'southern',
        'space',
        'speak',
        'special',
        'specific',
        'speech',
        'spend',
        'sport',
        'spring',
        'staff',
        'stage',
        'stand',
        'standard',
        'star',
        'start',
        'state',
        'statement',
        'station',
        'stay',
        'step',
        'still',
        'stock',
        'stop',
        'store',
        'story',
        'strategy',
        'street',
        'strong',
        'structure',
        'student',
        'study',
        'stuff',
        'style',
        'subject',
        'success',
        'successful',
        'such',
        'suddenly',
        'suffer',
        'suggest',
        'summer',
        'support',
        'sure',
        'surface',
        'system',
        'table',
        'take',
        'talk',
        'task',
        'tax',
        'teach',
        'teacher',
        'team',
        'technology',
        'television',
        'tell',
        'ten',
        'tend',
        'term',
        'test',
        'than',
        'thank',
        'that',
        'the',
        'their',
        'them',
        'themselves',
        'then',
        'theory',
        'there',
        'these',
        'they',
        'thing',
        'think',
        'third',
        'this',
        'those',
        'though',
        'thought',
        'thousand',
        'threat',
        'three',
        'through',
        'throughout',
        'throw',
        'thus',
        'time',
        'to',
        'today',
        'together',
        'tonight',
        'too',
        'top',
        'total',
        'tough',
        'toward',
        'town',
        'trade',
        'traditional',
        'training',
        'travel',
        'treat',
        'treatment',
        'tree',
        'trial',
        'trip',
        'trouble',
        'true',
        'truth',
        'try',
        'turn',
        'TV',
        'two',
        'type',
        'under',
        'understand',
        'unit',
        'until',
        'up',
        'upon',
        'us',
        'use',
        'usually',
        'value',
        'various',
        'very',
        'view',
        'visit',
        'voice',
        'vote',
        'wait',
        'walk',
        'wall',
        'want',
        'war',
        'watch',
        'water',
        'way',
        'we',
        'wear',
        'week',
        'weight',
        'well',
        'west',
        'western',
        'what',
        'whatever',
        'when',
        'where',
        'whether',
        'which',
        'while',
        'white',
        'who',
        'whole',
        'whom',
        'whose',
        'why',
        'wide',
        'wife',
        'will',
        'win',
        'wind',
        'window',
        'wish',
        'with',
        'within',
        'without',
        'woman',
        'wonder',
        'word',
        'work',
        'worker',
        'world',
        'worry',
        'would',
        'write',
        'writer',
        'wrong',
        'yard',
        'yeah',
        'year',
        'yes',
        'yet',
        'you',
        'young',
        'your',
        'yourself',
    )



from .. import Provider as BaseProvider

# Source: ONISEP
# data.gouv.fr/s/resources/liste-des-metiers-onisep/20150112-173428/metier.csv


class Provider(BaseProvider):
    jobs = ["Accessoiriste",
            "Accompagnateur de moyenne montagne",
            "Accompagnateur de tourisme équestre",
            "Accompagnateur de voyages",
            "Acheteur",
            "Acheteur d'espaces publicitaires",
            "Acousticien",
            "Actuaire",
            "Adjoint",
            "Administrateur de base de données",
            "Administrateur de biens",
            "Administrateur de logiciels de laboratoire",
            "Administrateur de mission humanitaire",
            "Administrateur de réseau",
            "Administrateur de spectacle",
            "Administrateur judiciaire ",
            "Agenceur de cuisines et salles de bains",
            "Agent",
            "Agent artistique",
            "Agent d'assurances ",
            "Agent de développement des énergies renouvelables",
            "Agent de développement local",
            "Agent de développement touristique",
            "Agent de la surveillance SNCF",
            "Agent de propreté et d'hygiène",
            "Agent de propreté urbaine",
            "Agent de sécurité",
            "Agent de service commercial train",
            "Agent des méthodes",
            "Agent de transit",
            "Agriculteur",
            "Agronome",
            "Aide médico-psychologique",
            "Aide-soignant",
            "Ajusteur",
            "Ambulancier",
            "Analyste de crédit",
            "Analyste financier",
            "Anatomiste",
            "Anesthésiste-réanimateur",
            "Animalier de laboratoire",
            "Animateur",
            "Animateur 2D et 3D",
            "Animateur d'activités physiques et sportives",
            "Animateur de bassin versant",
            "Animateur de radio et de télévision",
            "Animateur du patrimoine",
            "Animateur nature",
            "Antiquaire",
            "Apiculteur",
            "Aquaculteur",
            "Arboriculteur",
            "Architecte",
            "Architecte d'intérieur",
            "Architecte naval ",
            "Architecte produit industriel",
            "Architecte réseau",
            "Architecte web",
            "Archiviste",
            "Archéologue",
            "Aérodynamicien",
            "Aromaticien",
            "Artiste de cirque",
            "Ascensoriste",
            "Assistant",
            "Assistant",
            "Assistant",
            "Assistant de gestion en PME",
            "Assistant dentaire",
            "Assistant de service social",
            "Assistant en ressources humaines",
            "Astrophysicien",
            "Attaché",
            "Attaché",
            "Attaché d'administration",
            "Attaché de presse",
            "Attaché de recherche clinique",
            "Audioprothésiste",
            "Auditeur externe",
            "Auditeur interne",
            "Auteur interprète",
            "Auxiliaire de puériculture",
            "Auxiliaire de vie sociale",
            "Auxiliaire spécialisé vétérinaire",
            "Avocat",
            "Bactériologiste",
            "Barman ",
            "Batelier",
            "Bibliothécaire",
            "Bijoutier",
            "Bio-informaticien",
            "Biologiste en environnement",
            "Biologiste médical",
            "Biostatisticien",
            "Ébéniste",
            "Botaniste",
            "Bottier",
            "Boucher",
            "Boulanger",
            "Brodeur",
            "Bronzier",
            "Cadreur",
            "Caissier",
            "Canalisateur",
            "Carreleur-mosaïste",
            "Carrossier ",
            "Cartographe",
            "Caviste",
            "Chanteur",
            "Charcutier",
            "Chargé",
            "Chargé d'affaires en génie climatique",
            "Chargé d'affaires en génie mécanique",
            "Chargé de clientèle banque",
            "Chargé de communication interne",
            "Chargé de pharmacovigilance",
            "Chargé de production",
            "Chargé de projet événementiel",
            "Chargé de recherche en acoustique musicale",
            "Chargé de recherche et développement déchets",
            "Chargé de référencement web",
            "Chargé des méthodes outils et qualité en informatique",
            "Chargé des relations publiques",
            "Chargé de veille législative et réglementaire",
            "Chargé d'études économiques",
            "Chargé d'études en aménagement",
            "Chargé d'études en marketing",
            "Chargé d'études en valorisation agricole des déchets",
            "Chargé d'études média",
            "Chargé d'études naturalistes",
            "Chargé d'études ressources humaines",
            "Charpentier bois",
            "Charpentier métallique",
            "Chaudronnier",
            "Chauffeur de taxi",
            "Chef comptable",
            "Chef de chantier",
            "Chef de chantier en installations électriques",
            "Chef de cultures légumières",
            "Chef de fabrication des industries graphiques",
            "Chef de mission humanitaire",
            "Chef de produit marketing",
            "Chef de produit touristique",
            "Chef de projet biodiversité",
            "Chef de projet démantèlement nucléaire",
            "Chef de projet informatique",
            "Chef de projet multimédia",
            "Chef de projet éolien",
            "Chef de projet sites et sols pollués",
            "Chef de projet territorial",
            "Chef de publicité",
            "Chef de rayon",
            "Chef de station de traitement des eaux",
            "Chef des ventes",
            "Chef d'exploitation d'usine d'incinération",
            "Chef monteur",
            "Chercheur en biologie",
            "Chercheur en biologie du sport",
            "Chercheur en chimie",
            "Chercheur en physique   ",
            "Chirurgien",
            "Chirurgien-dentiste",
            "Éclairagiste",
            "Clerc d'huissier",
            "Climatologue",
            "Coffreur",
            "Cogniticien",
            "Coiffeur",
            "Collaborateur de notaire",
            "Collecteur de fonds",
            "Comédien",
            "Commerçant en alimentation",
            "Commercial export",
            "Commissaire de police",
            "Commissaire-priseur",
            "Comptable",
            "Concepteur",
            "Concepteur de jeux vidéo",
            "Concepteur de niveaux de jeu web",
            "Concepteur multimédia",
            "Conducteur",
            "Conducteur de bus ou d'autocar",
            "Conducteur de ligne de production alimentaire",
            "Conducteur de machines agricoles",
            "Conducteur de machines à imprimer ",
            "Conducteur de machines à papier ",
            "Conducteur de métro",
            "Conducteur d'engins de travaux publics",
            "Conducteur de scierie",
            "Conducteur de train / TGV",
            "Conducteur de travaux",
            "Économe de flux",
            "Économiste de la construction",
            "Conseiller agricole",
            "Conseiller d'éducation",
            "Conseiller d'insertion et de probation",
            "Conseiller d'orientation-psychologue",
            "Conseiller en économie sociale et familiale",
            "Conseiller en environnement",
            "Conseiller en fusion-acquisition",
            "Conseiller en génétique",
            "Conseiller en insertion sociale et professionnelle",
            "Conseiller en salle de remise en forme",
            "Conseiller en séjours",
            "Conseiller en voyages",
            "Conseiller espace info-énergie",
            "Conservateur du patrimoine",
            "Consignataire de navire",
            "Constructeur de routes",
            "Consultant",
            "Consultant en solutions intégrées",
            "Consultant en validation",
            "Consultant green IT",
            "Contrôleur",
            "Contrôleur",
            "Contrôleur de gestion",
            "Contrôleur de performances",
            "Contrôleur technique automobile",
            "Convoyeur de fonds",
            "Coordonnateur d'études cliniques",
            "Cordiste",
            "Cordonnier",
            "Correcteur",
            "Costumier",
            "Courtier",
            "Couvreur",
            "Céramiste",
            "Credit manager",
            "Cuisinier",
            "Danseur",
            "Déclarant en douane",
            "Décolleteur",
            "Décorateur scénographe",
            "Designer",
            "Designer d'interaction",
            "Designer sonore",
            "Dessinateur BTP",
            "Dessinateur de BD",
            "Dessinateur en construction mécanique",
            "Directeur",
            "Directeur artistique",
            "Directeur d'agence bancaire",
            "Directeur de centre pénitentiaire",
            "Directeur de création",
            "Directeur de la photographie",
            "Directeur de magasin à grande surface",
            "Directeur de restaurant",
            "Directeur d'hôpital",
            "Directeur d'hôtel",
            "Directeur d'office de tourisme",
            "Éditeur",
            "Diététicien",
            "Déménageur",
            "Démographe",
            "Documentaliste",
            "Domoticien",
            "Dépanneur en électroménager",
            "Dresseur d'animaux",
            "Éducateur",
            "Éducateur",
            "Éducateur",
            "Éducateur de jeunes enfants",
            "Éducateur de la protection judiciaire de la jeunesse",
            "Développeur économique",
            "Développeur d'applications mobiles",
            "Développeur humanitaire",
            "Développeur informatique",
            "Employé de pressing",
            "Employé de restaurant",
            "Encadreur",
            "Enquêteur privé",
            "Enseignant",
            "Enseignant",
            "Enseignant d'art",
            "Enseignant de la conduite automobile et de la sécurité routière",
            "Enseignant humanitaire",
            "Entraîneur ",
            "Entraîneur de chevaux",
            "Ergonome",
            "Ergothérapeute",
            "Esthéticien",
            "Ethnologue",
            "Expert automobile",
            "Expert bilan carbone",
            "Expert-comptable",
            "Expert en sécurité informatique",
            "Expert immobilier",
            "Façadier",
            "Facteur",
            "Facteur d'instruments",
            "Façonnier des industries graphiques",
            "Femme de chambre ",
            "Ferronnier d'art",
            "Fiscaliste",
            "Fleuriste",
            "Formateur d'adultes",
            "Formateur en informatique",
            "Formulateur",
            "Frigoriste",
            "Garde ",
            "Garde à cheval",
            "Gardien de la paix",
            "Gardien de police municipale",
            "Garçon de café",
            "Gendarme",
            "Gestionnaire de contrats d'assurance",
            "Gestionnaire de contrats informatiques",
            "Gestionnaire de données cliniques",
            "Gestionnaire de patrimoine",
            "Gestionnaire de portefeuille",
            "Généticien",
            "Géochimiste",
            "Géographe",
            "Géologue",
            "Géologue minier",
            "Géologue modélisateur",
            "Géomaticien",
            "Géomètre-topographe",
            "Géophysicien",
            "Géotechnicien",
            "Géothermicien",
            "Gouvernante",
            "Gérant de restauration collective",
            "Graphiste",
            "Greffier",
            "Grutier",
            "Guichetier",
            "Guide conférencier des villes et pays d'art et d'histoire",
            "Guide de haute montagne",
            "Guide-interprète",
            "Halieute",
            "Histologiste",
            "Horloger",
            "Horticulteur",
            "Hot liner",
            "Hôte d'accueil",
            "Hôtesse de l'air ",
            "Huissier de justice",
            "Hydraulicien",
            "Hydrogéologue",
            "Hydrologue",
            "Iconographe",
            "Illustrateur",
            "Infirmier",
            "Infirmier humanitaire",
            "Informaticien",
            " ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur",
            "Ingénieur analyste de l'air",
            "Ingénieur brevets",
            "Ingénieur calcul",
            "Ingénieur chimiste",
            "Ingénieur chimiste en développement analytique",
            "Ingénieur cloud computing",
            "Ingénieur d'application",
            "Ingénieur de la police technique et scientifique",
            "Ingénieur du BTP",
            "Ingénieur du son",
            "Ingénieur efficacité énergétique du bâtiment",
            "Ingénieur en aéronautique",
            "Ingénieur en automatisme",
            "Ingénieur en construction automobile",
            "Ingénieur en construction navale",
            "Ingénieur en génie climatique",
            "Ingénieur en informatique",
            "Ingénieur en électronique numérique",
            "Ingénieur en mécanique",
            "Ingénieur en mécanique",
            "Ingénieur en métrologie",
            "Ingénieur en énergie solaire",
            "Ingénieur en production et expérimentations végétales",
            "Ingénieur en R et D en énergies renouvelables",
            "Ingénieur environnement",
            "Ingénieur environnement et risques industriels",
            "Ingénieur essais",
            "Ingénieur fluides, énergies, réseaux, environnement",
            "Ingénieur forage",
            "Ingénieur gaz",
            "Ingénieur hydroécologue",
            "Ingénieur hydrogéomorphologue",
            "Ingénieur maintenance aéronautique",
            "Ingénieur métallurgiste",
            "Ingénieur méthodes mécaniques",
            "Ingénieur nucléaire",
            "Ingénieur plasturgiste",
            "Ingénieur procédés en chimie",
            "Ingénieur process aval",
            "Ingénieur production dans les biotechnologies",
            "Ingénieur production en mécanique",
            "Ingénieur radioprotection",
            "Ingénieur recherche et développement en agroalimentaire",
            "Ingénieur réservoir",
            "Ingénieur structures",
            "Ingénieur système",
            "Ingénieur systèmes embarqués",
            "Ingénieur technico-commerciale en électronique",
            "Ingénieur technico-commercial en chimie",
            "Ingénieur textile",
            "Ingénieur télécoms et réseaux",
            "Ingénieur études et développement en logiciels de simulation",
            "Inspecteur",
            "Inspecteur de banque",
            "Inspecteur du permis de conduire et de la sécurité routière",
            "Installateur en télécoms",
            "Intégrateur web",
            "Journaliste",
            "Journaliste reporter d'images ",
            "Juge des enfants",
            "Juge d'instance",
            "Juge d'instruction",
            "Juriste d'entreprise",
            "Juriste droit de l'environnement",
            "Juriste en droit social",
            "Juriste en propriété intellectuelle",
            "Lad-jockey, lad-driver",
            "Élagueur",
            "Électricien",
            "Électromécanicien ",
            "Électronicien automobile",
            "Éleveur",
            "Libraire",
            "Linguiste",
            "Logisticien",
            "Machiniste constructeur ou plateau",
            "Magasinier cariste",
            "Magistrat",
            "Manager de risques",
            "Mandataire judiciaire",
            "Manipulateur en électroradiologie médicale",
            "Maçon",
            "Maquettiste",
            "Maraîcher",
            "Maréchal",
            "Marchandiseur",
            "Marin de commerce",
            "Marin pêcheur",
            "Maroquinier",
            "Masseur-kinésithérapeute",
            "Matelot",
            "Maître-chien",
            "Maître  d'hôtel",
            "Maître nageur sauveteur",
            "Mécanicien",
            "Mécanicien",
            "Mécanicien bateaux",
            "Mécanicien d'entretien d'avion",
            "Mécanicien en matériel agricole",
            "Mécanicien moto",
            "Mécatronicien",
            "Médecin généraliste",
            "Médecin humanitaire",
            "Médecin spécialiste",
            "Médiateur",
            "Menuisier",
            "Microbiologiste",
            "Microtechnicien",
            "Militaire du rang ",
            "Militaire technicien",
            "Mixeur",
            "Modiste",
            "Modéliste",
            "Moniteur",
            "Moniteur de ski",
            "Moniteur d'équitation",
            "Monteur",
            "Monteur en installations thermiques et climatiques",
            "Monteur en réseaux de distribution électrique",
            "Mouleur",
            "Météorologiste",
            "Musicien",
            "Neurobiologiste",
            "Notaire",
            "Océanologue",
            "Oenologue",
            "Officier",
            "Officier de gendarmerie",
            "Officier de la marine marchande",
            "Officier de l'armée de l'air",
            "Officier de l'armée de terre",
            "Officier de marine",
            "Officier de police",
            "Opérateur de fabrication de produits alimentaires",
            "Opérateur de raffinerie",
            "Opérateur en traitement des matériaux",
            "Opérateur prépresse",
            "Opérateur sur machine à commande numérique",
            "Opticien",
            "Optronicien",
            "Orfèvre",
            "Orthophoniste",
            "Orthoprothésiste",
            "Orthoptiste",
            "Ostéopathe",
            "Ouvrier",
            "Ouvrier agricole",
            "Ouvrier paysagiste",
            "Palefrenier",
            "Paléontologue",
            "Parfumeur",
            "Paysagiste",
            "Pédiatre",
            "Pédicure-podologue",
            "Pédologue",
            "Peintre en bâtiment",
            "Pharmacien",
            "Pharmacien dans l'industrie",
            "Photographe",
            "Pilote de ligne",
            "Pilote de ligne automatisée ",
            "Plombier",
            "Plâtrier",
            "Podo-orthésiste",
            "Professeur dans l'enseignement agricole",
            "Professeur d'éducation physique et sportive",
            "Professeur de collège et de lycée",
            "Professeur de lycée professionnel ou technique ",
            "Professeur de maths ou de physique-chimie",
            "Professeur de musique et de danse",
            "Professeur des écoles ",
            "Professeur documentaliste",
            "Projectionniste",
            "Prothésiste dentaire",
            "Préparateur en pharmacie",
            "Psychanalyste",
            "Psychologue",
            "Psychomotricien",
            "Pâtissier",
            "Puériculteur",
            "Qualiticien",
            "Réceptionniste",
            "Rédacteur",
            "Rédacteur en chef",
            "Rédacteur on line",
            "Relieur",
            "Reporter-photographe",
            "Responsable assurance qualité",
            "Responsable biométrie",
            "Responsable de fabrication en agroalimentaire",
            "Responsable de formation",
            "Responsable de laboratoire de contrôle en biologie",
            "Responsable de la collecte des déchets ménagers",
            "Responsable de la promotion des ventes",
            "Responsable de la rémunération",
            "Responsable de plate-forme biotechnologique",
            "Responsable de projets culturels",
            "Responsable de réseau d'assainissement",
            "Responsable de réseau eau potable",
            "Responsable de scierie",
            "Responsable de site de traitement des déchets",
            "Responsable des ressources humaines",
            "Responsable d'ordonnancement",
            "Responsable du back-office",
            "Responsable du recrutement",
            "Responsable du service après-vente",
            "Responsable du soutien logistique intégré",
            "Responsable micro",
            "Responsable qualité en agroalimentaire",
            "Restaurateur d'oeuvres d'art",
            "Régisseur cinéma",
            "Régisseur de spectacles",
            "Régleur",
            "Rudologue",
            "Sage-femme ",
            "Salesman",
            "Sapeur",
            "Scénariste",
            "Scripte",
            "Secrétaire",
            "Secrétaire administratif",
            "Secrétaire d'édition",
            "Secrétaire de rédaction",
            "Secrétaire des Affaires étrangères",
            "Secrétaire juridique",
            "Secrétaire médical",
            "Sellier",
            "Serrurier",
            "Sociologue",
            "Soigneur",
            "Solier-moquettiste",
            "Sommelier",
            "Soudeur",
            "Souffleur de verre ",
            "Souscripteur",
            "Sous-officier de l'armée de l'air",
            "Sous-officier de l'armée de terre",
            "Spécialiste des affaires réglementaires en chimie",
            "Sportif de haut niveau",
            "Sérigraphe",
            "Staffeur-ornemaniste",
            "Statisticien",
            "Styliste ",
            "Substitut du procureur",
            "Surveillant de centre pénitentiaire",
            "Syndic de copropriété",
            "Tailleur",
            "Tailleur de pierre",
            "Étalagiste",
            "Étanchéiste",
            "Tapissier d'ameublement ",
            "Technicien ",
            "Technicien ",
            "Technicien",
            "Technicien",
            "Technicien",
            "Technicien automobile",
            "Technicien biologiste",
            "Technicien chimiste",
            "Technicien céramiste",
            "Technicien d'analyses biomédicales",
            "Technicien de fabrication de mobilier et de menuiserie",
            "Technicien de forge",
            "Technicien de l'intervention sociale et familiale",
            "Technicien de maintenance en génie climatique",
            "Technicien de maintenance en informatique",
            "Technicien de maintenance industrielle",
            "Technicien de police technique et scientifique",
            "Technicien des industries du verre",
            "Technicien d'essais",
            "Technicien d'exploitation de l'eau",
            "Technicien d'exploitation du réseau gaz",
            "Technicien d'intervention clientèle gaz",
            "Technicien en automatismes",
            "Technicien en engins de travaux publics",
            "Technicien en lignes haute tension ",
            "Technicien en métrologie",
            "Technicien en optique de précision",
            "Technicien en traitement des déchets",
            "Technicien nucléaire",
            "Technicien paysagiste",
            "Technicien plasturgiste",
            "Technicien télécoms et réseaux",
            "Technico-commercial en agroalimentaire",
            "Techniverrier",
            "Teinturier",
            "Testeur en informatique",
            "Télévendeur",
            "Toiletteur d'animaux",
            "Tonnelier",
            "Trader",
            "Traducteur-interprète",
            "Urbaniste",
            "Veilleur stratégique",
            "Vendeur-conseil en matériel agricole",
            "Vendeur en animalerie",
            "Vendeur en fournitures automobiles",
            "Vendeur en magasin",
            "Vendeur en micro-informatique et multimédia",
            "Verrier au chalumeau",
            "Visiteur",
            "Viticulteur",
            "Vitrailliste",
            "Volcanologue",
            "Vétérinaire",
            "Webdesigner",
            "Webmestre",
            "Zoologiste"]



from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """
    List of 2000 most frequent words in Polish Wiktionary

    https://pl.wiktionary.org/wiki/Indeks:Polski_-_Najpopularniejsze_s%C5%82owa_1-2000
    """

    word_list = (
        'w', 'z', 'być', 'na', 'i', 'do', 'nie', 'to', 'który', 'lub', 'się', 'mieć', 'o', 'coś', 'ten', 'dotyczyć',
        'co', 'on', 'ktoś', 'od', 'język', 'że', 'po', 'przez', 'ja', 'jeden', 'miasto', 'za', 'osoba', 'jak', 'rok',
        'cecha', 'a', 'bardzo', 'taki', 'mój', 'człowiek', 'imię', 'swój', 'dla', 'związać', 'część', 'kobieta', 'dwa',
        'móc', 'ona', 'pan', 'nasz', 'jakiś', 'mały', 'ze', 'miejsce', 'inny', 'bez', 'czas', 'duży', 'związany',
        'praca', 'czy', 'ale', 'pies', 'sposób', 'Polska', 'rodzaj', 'tylko', 'dom', 'dziecko', 'np.', 'ty', 'dzień',
        'mieszkaniec', 'jako', 'rzeka', 'przed', 'pani', 'męski', 'woda', 'tak', 'pod', 'dobry', 'już', 'państwo',
        'rodzina', 'zostać', 'życie', 'mówić', 'zwierzę', 'nad', 'pierwszy', 'ta', 'przy', 'wiele', 'cały', 'roślina',
        'u', 'sobie', 'trzy', 'nowy', 'często', 'chcieć', 'kolor', 'musieć', 'używać', 'robić', 'wielki', 'żeński',
        'kraj', 'mężczyzna', 'jego', 'strona', 'wysoki', 'każdy', 'nazwa', 'gatunek', 'polski', 'iść', 'sam', 'stolica',
        'grupa', 'stary', 'my', 'zrobić', 'książka', 'kto', 'symbol', 'drugi', 'rzecz', 'stan', 'samochód', 'drzewo',
        'ptak', 'między', 'świat', 'prawo', 'sąsiad', 'droga', 'oraz', 'słowo', 'mieszkanka', 'głowa', 'liczba', 'ci',
        'oni', 'nie-', 'codziennie', 'owoc', 'gdy', 'młody', 'środek', 'zły', 'spotykać', 'bo', 'raz', 'spacer',
        'ziemia', 'liczba atomowa', 'aby', 'znajdować się', 'należeć', 'itp.', 'ojciec', 'dużo', 'wiek', 'Rosja',
        'dobrze', 'kiedy', 'służyć', 'kilka', 'przedmiot', 'ręka', 'jaki', 'biały', 'długi', 'sprawa', 'cztery',
        'siebie', 'podczas', 'ruch', 'okres', 'góra', 'żona', 'litera', 'matka', 'odnosić się', 'kupić', 'pięć',
        'widzieć', 'zawsze', 'oko', 'albo', 'zajmować się', 'jeszcze', 'stać', 'szkoła', 'forma', 'we', 'pracować',
        'cel', 'koniec', 'twój', 'ciało', 'wiedzieć', 'mieszkać', 'zwykle', 'niż', 'działanie', 'koń', 'pokój',
        'element', 'kwiat', 'nauka', 'godzina', 'wszystko', 'zawierać', 'gdzie', 'położyć', 'powiedzieć',
        'pierwiastek chemiczny', 'urządzenie', 'choroba', 'lubić', 'pochodzić', 'wyspa', 'syn', 'prowadzić', 'piękny',
        'dać', 'wszyscy', 'miesiąc', 'wieś', 'jednostka', 'ryba', 'światło', 'jeść', 'dziewczyna', 'żyć', 'by', 'dawać',
        'budynek', 'stopień', 'grać', 'herb', 'brat', 'las', 'jej', 'siła', 'obszar', 'czarny', 'nic', 'znak', 'dany',
        'one', 'żeby', 'czerwony', 'rząd', 'różny', 'brak', 'dziś', 'gra', 'leżeć', 'związek', 'członek', 'kształt',
        'chodzić', 'wykonywać', 'wartość', 'noc', 'obwód', 'sztuka', 'statek', 'teraz', 'noga', 'dźwięk', 'występować',
        'teren', 'ostatni', 'pieniądz', 'sytuacja', 'wczoraj', 'śmierć', 'tydzień', 'sklep', 'niebo', 'niektóry',
        'morze', 'ważny', 'także', 'film', 'krótki', 'Europa', 'działać', 'główny', 'tworzyć', 'wykonać', 'skóra',
        'sześć', 'tam', 'materiał', 'trwać', 'dwadzieścia', 'ilość', 'wino', 'kot', 'szybko', 'określony', 'lecz',
        'własny', 'wojna', 'pochodzenie', 'pole', 'powierzchnia', 'północny', 'flaga', 'przyjaciel', 'postać', 'znać',
        'silny', 'proces', 'władza', 'mleko', 'system', 'mięso', 'obraz', 'składać się', 'wyraz', 'tysiąc', 'głos',
        'pić', 'południowy', 'słońce', 'serce', 'początek', 'córka', 'Bóg', 'pisać', 'jechać', 'drzwi', 'twarz',
        'region', 'firma', 'miłość', 'wiatr', 'zielony', 'tekst', 'jeśli', 'zmiana', 'grecki', 'kierunek', 'siedem',
        'święty', 'nawet', 'król', 'niski', 'wolny', 'koło', 'linia', 'kawa', 'dzisiaj', 'chleb', 'ulica', 'siostra',
        'dawny', 'czyjś', '1000', 'nosić', 'problem', 'powietrze', 'włos', 'prosty', 'więc', 'układ okresowy', 'pomoc',
        'żołnierz', 'brać', 'wziąć', 'tu', 'posiadać', 'powodować', 'uważać', 'punkt', 'ogień', 'arabski', 'podobny',
        'stanowić', 'ludzie', 'charakterystyczny', 'mało', 'jezioro', 'właściwy', 'pewien', 'mąż', 'też', 'trzeci',
        'krew', 'brzeg', 'dziesięć', 'samolot', 'znaleźć', 'okno', 'znaczenie', 'osiem', 'pójść', '1', 'gwiazda',
        'informacja', 'granica', 'oddział', 'prawdziwy', 'dostać', 'powinien', 'ich', 'nigdy', 'drewno', 'stosować',
        'zbiór', 'Ukraina', 'chwila', 'ból', 'uwaga', 'niewielki', 'charakter', 'deszcz', 'czysty', 'zachowanie',
        'ciężki', 'badanie', 'ostry', 'alfabet', 'Niemcy', 'ząb', 'żaden', 'Francja', 'zacząć', 'ile', 'położenie',
        'niemiecki', 'myśleć', 'wynik', 'pracownik', 'piwo', 'walka', 'polegać', 'francuski', 'stół', 'stać się',
        'pierwiastek', 'według', 'chory', 'zasada', 'można', 'but', 'śnieg', 'pociąg', 'utwór', 'zespół', 'kościół',
        'dziewięć', 'nauczyciel', 'siedzieć', 'lekarz', 'łączyć', 'prawy', 'istnieć', 'jutro', 'trudny', 'zbyt',
        'kamień', 'jedzenie', 'liść', 'jasny', 'kultura', 'czynność', 'południe', 'numer', 'mieszkanie', 'klasa',
        'zdanie', 'historia', 'wydawać', 'ściana', 'funkcja', 'żółty', 'ubranie', 'bóg', 'muzyka', 'piec',
        'przypominać', 'uczeń', 'układ', 'księżyc', 'zwłaszcza', 'historyczny', 'komputer', 'rosnąć', 'substancja',
        'chłopiec', 'zachodni', 'również', 'prawda', 'organizm', 'pełny', 'program', 'całość', 'uczucie', 'urząd',
        'starożytny', 'typ', '2', 'polityczny', 'alkohol', 'głupi', 'północ', 'jednak', 'spać', 'pojazd', 'bliski', '5',
        'uprawiać', 'wszystkie', 'para', 'złoty', 'kraina', 'elektryczny', 'cena', 'organizacja', 'przyjść', 'około',
        'niebieski', 'prosić', 'towar', 'przypadek', 'trzeba', 'list', 'źródło', 'ludzki', 'dokument', 'społeczny',
        'herbata', 'kawałek', 'dziedzina', 'słaby', 'myśl', 'dopływ', 'wiedza', 'narzędzie', 'ani', 'lewy', 'naczynie',
        'błąd', 'szybki', 'wojskowy', 'znany', 'wieczór', 'trochę', 'wschodni', 'naturalny', 'zupa', 'pewny', 'trzymać',
        'lód', 'trzydzieści', 'może', 'szeroki', 'zjawisko', 'ogród', 'przeznaczyć', 'przeciwny', 'angielski', 'czytać',
        'ciasto', 'drobny', 'kochać', 'maszyna', 'chłopak', 'sen', 'plan', 'głównie', 'składać', 'wokół', 'produkt',
        'napój', 'wielkość', 'zdjęcie', 'zima', 'zobaczyć', 'energia', 'łóżko', 'obywatel', 'złoto', 'broń', 'tkanina',
        'słodki', 'pytanie', 'mowa', 'województwo', 'spotkanie', 'publiczny', 'obiekt', 'smak', 'karta', 'pełen',
        'większość', 'cukier', 'cześć', 'wpływ', 'wodny', '4', 'stopa', 'Włochy', 'stosunek', 'kuchnia', 'odbywać się',
        'duch', 'morski', 'w celu', 'aż', 'wybrzeże', 'pismo', 'prowincja', 'razem', 'równy', 'stały', 'pięćdziesiąt',
        'wewnątrz', 'prawie', 'gość', 'powstać', 'mocny', 'jajko', 'naród', 'potrawa', 'papier', 'butelka', 'temat',
        'żywy', 'rejon', 'zdrowie', 'lekki', 'sąd', 'palić', 'nikt', 'instrument', '3', 'wiadomość', 'produkcja', 'nos',
        'dziadek', 'palec', 'kość', 'długość', 'obejmować', 'partia', 'Afryka', 'lato', 'rola', 'zapach', 'księga',
        'policja', 'za pomocą', 'czynić', 'udział', 'czekać', 'rower', 'wszystek', 'miejscowość', 'sieć', 'babcia',
        'muzyczny', 'poza', 'odpowiedni', 'usta', 'warstwa', 'lek', 'podstawowy', 'wy', 'chemiczny', 'czterdzieści',
        'zabawa', 'szczyt', 'ponieważ', 'gmina', 'nie ma', 'warunek', 'jabłko', 'wojsko', 'wyrażać', 'powód',
        'rozumieć', 'ciemny', 'słownik', 'długo', 'mama', 'śpiewać', 'środkowy', 'podstawa', 'rano', 'opinia',
        'Hiszpania', 'wyjść', 'religia', 'pozycja', 'wschód', 'zachód', 'fala', 'wydarzenie', 'bogaty', 'piłka',
        'Ziemia', 'Azja', 'ramię', 'sześćdziesiąt', 'właśnie', 'poprzez', 'ucho', 'wypadek', 'gruby', 'nazywać', '30',
        'tytuł', 'stanowisko', 'krowa', 'szczęście', 'obok', 'oficjalny', 'poziom', 'odmiana', 'rosyjski', 'połowa',
        'rozmowa', 'gazeta', 'rodzic', 'ponad', 'potrzeba', 'szukać', 'połączenie', 'wyglądać', 'zbierać', 'rozwój',
        'pogoda', 'masa', 'pomieszczenie', 'potem', 'dzieło', 'nazwisko', 'sól', 'odpowiadać', 'całkowicie',
        'posługiwać się', 'styl', 'sto', 'strach', 'lud', 'religijny', 'papieros', 'słuchać', 'styczeń', 'podróż',
        'głęboki', 'środowisko', 'administracyjny', 'moc', 'pogląd', 'centrum', 'górski', 'święto', 'kara',
        'instytucja', 'pas', 'Grecja', 'szczęśliwy', 'pozbawić', 'zadanie', 'zaczynać', 'taniec', 'korona', 'patrzeć',
        'oznaczać', 'temperatura', 'niedziela', 'listopad', 'chmura', 'zupełnie', 'wśród', 'liczyć', '6', 'otrzymać',
        'metoda', 'ono', 'zdolność', 'gorący', 'zajmować', 'wspólny', 'miły', 'możliwość', 'ładny', 'wejść',
        'wykorzystywać', 'egzamin', 'złożyć', 'wąski', 'skrzydło', 'fizyczny', 'przestrzeń', '100', 'przedstawiać',
        'otwarty', 'komórka', 'kierować', 'nóż', 'płyn', 'gdzieś', 'budowa', 'wspaniały', 'włoski', 'płynąć',
        'więzienie', 'zazwyczaj', 'seksualny', 'szpital', 'nagle', 'grzyb', 'ciepły', 'zmieniać', 'ser', 'wewnętrzny',
        'telefon', 'dlaczego', 'stawać się', 'kupować', 'walczyć', '900', 'zamek', 'dziki', 'zimny', 'minuta',
        'wywoływać', 'obecnie', 'dusza', '8', '10', 'obiad', 'określenie', 'wysokość', 'narodowy', 'europejski',
        'założyć', 'umrzeć', 'tutaj', 'czwarty', 'domowy', 'wierzyć', 'stworzyć', 'moneta', 'wobec', 'barwa',
        'właściwość', 'istota', 'możliwy', 'metal', 'naprawdę', 'umowa', 'węgiel', 'hiszpański', 'pierś', '9', 'trawa',
        'wygląd', 'określać', 'skała', 'przyrząd', 'osiemdziesiąt', 'ogromny', 'wąż', 'ku', 'wchodzić', 'ponownie',
        'natura', 'blisko', 'obowiązek', 'gaz', 'miara', 'z powodu', 'te', 'szczególnie', 'potrzebować', 'stracić',
        'wymagać', 'ludność', 'świnia', 'wcześnie', 'bieg', 'wrogi', 'miękki', 'autobus', 'drogi', 'zakład',
        'amerykański', 'siedemdziesiąt', 'grudzień', 'obcy', 'napisać', 'kolejny', 'sobą', 'ochrona', 'akcja',
        'Szwecja', 'rzymski', 'zwolennik', 'ziemniak', 'piąty', 'zdobyć', '20', 'dach', 'należy', 'bić', 'dział',
        'jeździć', 'pomiędzy', 'klucz', 'artykuł', 'zgoda', 'dziewięćdziesiąt', 'źle', 'ofiara', 'piasek', 'nadzieja',
        'moment', 'uniwersytet', 'Warszawa', 'pamięć', 'odpowiedź', 'luty', 'użycie', 'chronić', 'próbować', 'wyrób',
        'łatwo', 'przyczyna', 'wrzesień', 'teatr', 'przyjąć', 'dodatek', 'czyli', 'specjalista', 'sok', '7', 'decyzja',
        'przemysł', 'rynek', 'owca', 'prezydent', 'spokój', 'radość', 'drużyna', 'miejski', 'wróg', 'dół', 'podawać',
        'Jan', 'kolega', 'odcień', 'zakładać', 'sportowy', 'wolność', 'znowu', 'czuć', 'ten sam', 'owad', 'zatoka',
        'działalność', 'wiosna', 'warzywo', 'pragnienie', 'ogół', 'przykład', 'górny', 'róg', 'cierpieć', 'połączyć',
        'brzuch', 'surowy', 'polityka', 'Rzym', 'uczyć się', 'ogon', 'kula', 'kąt', 'wzrost', 'dokładnie', 'bilet',
        'tamten', 'wzór', 'cienki', 'poważny', 'wychodzić', 'padać', 'właściciel', 'rozmawiać', 'student',
        'międzynarodowy', 'szósty', 'Japonia', 'poruszać się', 'porządek', 'przyjmować', 'uderzenie', 'szacunek',
        'postępowanie', 'bok', 'rada', 'skład', 'koncern', 'przynosić', 'umieć', 'drewniany', 'atak', 'nadawać',
        'pióro', 'dziać się', 'przyjęcie', 'lekcja', 'poniedziałek', 'japoński', 'tradycyjny', 'potrafić', 'obecny',
        'wnętrze', 'kwiecień', 'republika', 'naukowy', 'leczenie', 'późno', 'prąd', 'maj', 'gwałtowny', 'uczyć',
        'terytorium', 'małżeństwo', 'prasa', 'mocno', 'państwowy', 'rzucać', 'dialekt', 'twardy', 'sprzedawać', 'płyta',
        'przyszłość', 'wiersz', 'biedny', 'mapa', 'zamieszkiwać', 'piątek', 'lipiec', 'ciągle', 'lew', 'marzec',
        'jesień', 'obchodzić', 'proszę', 'planeta', 'dzięki', '50', 'wilk', 'łatwy', 'milion', 'gwiazdozbiór', '40',
        'termin', 'pusty', 'wtedy', 'wydać', 'struktura', 'sobota', 'popularny', 'ssak', 'gałąź', 'pieniądze',
        'przeciw', 'technika', 'pół', 'zdrowy', 'więcej', 'świeży', 'szyja', 'zamknąć', 'sala', 'akt', 'wiara',
        'pływać', 'pszczoła', 'projekt', 'jedyny', 'bać się', 'zewnętrzny', 'płaski', 'spokojny', 'zwyczaj', 'organ',
        'sztuczny', 'delikatny', 'typowy', 'literatura', 'budować', 'strój', 'literacki', 'krzew', 'zawód', 'łagodny',
        'następny', 'chiński', 'Słońce', 'telewizja', 'zwykły', 'widoczny', 'piosenka', 'silnik', 'waga', 'płeć',
        'Stany Zjednoczone', 'komputerowy', 'dlatego', 'służba', 'suchy', 'modlitwa', 'sierpień', 'dość', 'kino',
        'siedziba', 'miód', 'lotniczy', 'Chiny', 'specjalny', 'dym', 'zysk', 'podatek', 'wejście', 'pomagać', 'zakres',
        'zwrot', 'fakt', 'otwór', 'pokryć', 'most', 'sprawiać', 'wybór', 'osiągnąć', 'siódmy', 'społeczeństwo',
        'fabryka', 'słyszeć', 'internetowy', 'mysz', 'przyjemność', 'bądź', 'przechodzić', 'próba', 'panować',
        'straszny', 'wrogość', 'zabić', 'przedsiębiorstwo', 'jajo', 'rzeczywistość', 'ziarno', 'restauracja',
        'współczesny', 'krok', 'daleko', 'składnik', 'kanał', 'kalendarz', 'odległość', 'przeciwnik', 'złapać', 'czyn',
        'mur', 'zmienić', 'kurs', 'niebezpieczny', 'Czechy', 'wtorek', 'ocena', 'postawić', 'okolica', 'usterka',
        'zjeść', 'umiejętność', 'zapomnieć', 'Anglia', 'dzielić', 'pamiętać', 'szef', 'majątek', 'kosztować', 'port',
        'spotkać', 'autor', 'los', 'dwudziesty', 'zdarzenie', 'ósmy', 'ślub', 'dopiero', 'prywatny', 'pojechać',
        'policjant', 'sędzia', 'średni', 'rzeczownik', 'ciepło', 'badać', 'rasa', 'Dania', 'koszula', 'okazja',
        'przeciwko', 'usługa', 'stawiać', 'otwierać', 'efekt', 'kapelusz', 'kaczka', 'własność', 'model', 'mięsień',
        'zgodnie', 'podać', 'piłka nożna', 'reakcja', 'znów', 'przejaw', 'doświadczenie', 'dziura', 'bitwa', 'korzyść',
        'bank', 'Indie', 'gniew', 'przedstawienie', 'naj-', 'czasownik', 'jakość', 'dłoń', 'osioł', 'hotel', 'sprzedaż',
        'kierowca', 'różnica', 'bohater', 'masło', 'wrażenie', 'brzydki', 'rozmiar', 'rzadko', 'królowa', 'przejść',
        'olej', 'śniadanie', 'artysta', 'pisarz', 'zamykać', 'opowiadać', 'plaża', 'słoneczny', 'prędkość', 'mąka',
        'Polak', 'ciąża', 'gęsty', 'zero', 'dawno', 'przyjemny', 'spowodować', 'brudny', 'wytwarzać', 'opisać',
        'okrągły', 'ciecz', 'ludowy', 'wrócić', 'dokonywać', 'kiedyś', 'wola', 'waluta', 'całkowity', 'wykonanie',
        'dziwny', 'tracić', 'wczesny', 'jazda', 'uderzać', 'radio', 'wyrażenie', 'wizyta', 'rana', 'daleki', 'czasem',
        'wybrać', 'fałszywy', 'pozwalać', 'złożony', 'klasztor', 'zawodnik', 'minerał', 'znajdować', 'przyszły',
        'koszt', 'spodnie', 'przepis', 'stacja', 'rzadki', 'grób', 'mecz', 'dyskusja', 'sport', 'nieszczęście', 'pieśń',
        'wolno', 'handel', 'korzeń', 'łaciński', 'penis', 'październik', 'głód', 'srebro', 'kontakt', 'budzić',
        'czwartek', 'otaczać', 'prostytutka', 'tradycja', 'znosić', 'gniazdo', 'złodziej', 'godny', 'powoli', 'zegar',
        'urzędnik', 'Rumunia', 'Egipt', 'metr', 'kolano', 'przestać', 'uderzyć', 'Turcja', 'przerwa', 'skończyć',
        'jeżeli', 'sądzić', 'transport', 'dobro', 'przygotować', 'szkolny', 'mi', 'małpa', 'udać się', 'krzyż',
        'atmosfera', 'klient', 'brązowy', 'tłuszcz', 'ślad', 'mebel', 'zakończenie', 'USA', 'coraz', 'wódka', 'danie',
        'sos', 'liczny', 'oddawać', 'zachowywać się', 'kontrola', 'mózg', 'bezpieczeństwo', 'duński', 'oglądać',
        'dodawać', 'urodziny', 'figura', 'powiat', 'dzisiejszy', 'otworzyć', 'armia', 'zboże', 'czerwiec', 'opłata',
        'skutek', 'suma', 'wyjście', 'operacja', 'niedźwiedź', 'matematyka', 'zniszczyć', 'pokazywać', 'zbudować',
        'kontynent', 'dwanaście', 'dodatkowy', 'fragment', 'łódź', 'szary', '80', 'ojczyzna', 'tańczyć',
        'Boże Narodzenie', 'umysł', 'Ameryka', 'ogólny', 'azjatycki', 'bydło', 'biblioteka', 'żart', 'rozwiązanie',
        'lecieć', 'pojęcie', 'konstrukcja', 'Austria', 'niech', 'niebezpieczeństwo', 'tyle', 'podłoga', 'wysoko',
        'odczuwać', 'obrona', 'żelazo', 'studiować', 'środa', 'park', 'powstawać', 'łuk', 'dolina', 'przygotowywać',
        'obywatelka', 'gotowy', 'miecz', 'uchodzić', 'szkoda', 'zgodny', 'dzielnica', 'prezent', 'sukces', '90',
        'lista', 'towarzystwo', 'podział', 'wysiłek', 'stado', 'tajemnica', 'kłopot', 'łyżka', 'lęk', 'cebula',
        'płacić', 'no', 'profesor', 'w czasie', 'niszczyć', 'm.in.', 'Afganistan', 'usuwać', 'pomysł', 'mrówka',
        'Kraków', 'gotować', 'norma', 'całkiem', 'finansowy', 'tor', 'temu', 'jądro', 'wracać', 'Białoruś', 'koza',
        'Jezus', 'płaszcz', 'wierny', 'różowy', 'widok', 'sygnał', 'cesarz', 'potrzebny', 'nagły', 'wypowiedź', 'kosz',
        'królestwo', 'samochodowy', 'artystyczny', '60', 'Chrystus', 'anioł', 'przejście', 'krzesło', 'sprzęt',
        'wskazywać', 'ksiądz', 'strumień', 'metalowy', 'wykonywanie', 'zmarły', 'chrześcijański', 'cierpienie', 'scena',
        'przeszkoda', 'zimno', 'mieć na imię', 'przychodzić', 'słoń', 'odwaga', 'przedstawiciel', 'aktor', 'ciekawy',
        'dziewiąty', 'Australia', 'smutny', 'biec', 'przyprawa', 'prawny', 'tłum', 'interes', 'studia', 'świątynia',
        'pijany', 'użytkownik', 'kostka', 'wywołać', 'wujek', 'dodać', 'robotnik', 'powszechny', 'dyrektor',
        'umieszczać', 'robota', 'narząd', 'szwedzki', 'turecki', 'otrzymywać', 'produkować', 'zabawka', 'kolejowy',
        'nastrój', 'szkło', 'ziemski', 'farba', 'bycie', 'zainteresowanie', 'relacja', 'ciężar', 'pasmo', 'wynosić',
        'obóz', 'marka', 'szczególny', 'lis', 'wada', 'Holandia', 'bogini', 'uciekać', 'dziewczynka', 'przestępstwo',
        'wycieczka', 'tablica', 'kolej', 'natychmiast', 'zdolny', 'wysyłać', 'błoto', 'Szwajcaria', 'orzeł', 'oddech',
        'motyl', 'kilometr', 'umożliwiać', 'żydowski', 'gospodarka', 'pomóc', 'wciąż', 'intensywny', 'wakacje', 'pytać',
        'utrzymywać', 'gdyby', 'malować', 'samica', 'istotny', 'idea', 'posiłek', 'wszelki', 'seks', 'pomarańczowy',
        'handlowy', 'czoło', 'przynieść', 'teoria', 'staw', 'obserwować', 'po prostu', 'Izrael', 'opieka', 'mgła',
        'osobisty', 'znaczyć', 'impreza', 'powieść', 'archipelag', 'nadmierny', 'reguła', 'pojedynczy', 'szklanka',
        'wóz', 'odcinek', 'telewizyjny', 'róża', 'zawartość', 'ryż', 'poznać', 'jedynie', 'polityk', 'zwycięstwo',
        'władca', 'żaba', 'zbiornik', 'mistrz', 'procent', 'zawodowy', 'obowiązywać', 'choć', 'kura', 'ćwiczenie',
        'chłop', 'świeca', 'promień', 'spadek', 'trudność', 'szereg', 'cień', 'epoka', 'umieścić', 'doskonały',
        'ozdobny', 'chociaż', 'kościelny', 'wyścig', 'zamiast', 'ocean', 'koncert', 'wybierać', 'znaczny',
        'chrześcijaństwo', 'bar', 'gołąb', 'postawa', 'kolacja', 'wina', 'pora', 'pragnąć', 'zakończyć', 'bieda',
        'Węgry', 'smutek', 'biuro', 'wieczorem', 'dolny', 'byk', 'burza', 'katolicki', 'książę', 'samiec', 'grzech',
        'naukowiec', 'kończyć', 'dorosły', 'zapalenie', 'przyjaźń', 'godność', 'fotografia', 'nieprzyjemny', 'mądry',
        'klimat', 'muzeum', 'treść', 'rezultat', 'dane', 'cisza', 'zaś', 'psychiczny', 'starać się', 'lampa', 'wesoły',
        'Unia Europejska', 'dziób', 'traktować', 'przeprowadzać', 'piętro', 'niezwykły', 'wieża', 'pokarm', 'igła',
        'strefa', 'spór', 'dać się', 'Estonia', 'poprzedni', 'dowód', 'pasek', 'dno', 'klub', 'wysłać', 'rachunek',
        'odkryć', 'gardło', 'piętnaście', 'nauczycielka', 'bawić się', 'królewski', 'lotnisko', 'wzrok', 'moralny',
        'odzież', 'śmiać się', 'mnóstwo', 'czapka', 'wywodzić się', 'sądowy', 'papież', 'plemię', 'kartka', '70',
        'tani', 'pożar', 'półwysep', 'kult', 'łąka', 'lot', 'broda', 'wspólnota', 'wreszcie', 'lata', 'powolny',
        'przybyć', 'mocz', 'Słowacja', 'grunt', 'pomidor', 'dokładny', 'stowarzyszenie', 'r.', 'wojenny', 'odważny',
        'podnosić', 'zeszły', 'ośrodek', 'ozdoba', 'wraz', 'tytoń', 'obrót', 'zmęczony', 'głośny', 'parlament',
        'uzyskać', 'wydawać się', 'budowla', 'jakby', 'wniosek', 'zajęcie', 'rysunek', 'wzgląd', 'pająk',
        'Morze Śródziemne', 'Litwa', 'jednocześnie', 'diabeł', 'pozostać', 'kłaść', 'skłonność', 'dziecięcy',
        'korzystać', 'Belgia', 'lina', 'wystawa', 'ciągnąć', 'pacjent', 'świadczyć', 'narkotyk', 'sukienka',
        'techniczny', 'zaraz', 'Wielka Brytania', 'medycyna', 'przyjechać', 'powstanie', 'trwały', 'wzbudzać',
        'czynnik', 'strata', 'podróżować', 'hałas', 'rak', 'talerz', 'plecy', 'późny', 'deska', 'boleć', 'spaść',
        'martwy', 'łańcuch', 'czeski', 'filmowy', 'wygrać', 'zaufanie', 'alkoholowy', 'płakać', 'głupiec', 'poczta',
        'dar', 'w formie', 'narodowość', 'podnieść', 'okręt', 'gęś', 'oś', 'nasiono', 'śmiech', 'tył', 'woleć', 'islam',
        'sowa', 'wpaść', 'panna', 'chyba', 'osiągnięcie', 'trudno', 'robak', 'otoczenie', 'konflikt', 'centralny',
        'pustynia', 'gabinet', 'poruszać', 'hasło', 'świecić', 'kij', 'przód', 'etap', 'większy', 'filozofia',
        'jedenaście', 'wstyd', 'kobiecy', 'urzędowy', 'czekolada', 'ciemność', 'zapis', 'ubogi', 'wioska', 'biskup',
        'doktor', 'oczywiście', 'wisieć', 'tłumaczenie', 'kwestia', 'kogut', 'oddać', 'ślepy', 'latać', 'babka',
        'dokonać', 'bogactwo', 'śmieć', 'analiza', 'strzelać', 'mierzyć', 'ciotka', 'blady', 'pozostawać', 'tłumaczyć',
        'muzyk', 'zgadzać się', 'paliwo', 'Żyd', 'postępować', 'bronić', 'szkodliwy', 'zanim', 'włosy', 'zatrzymać',
        'aktywny', 'skala', 'cmentarz', 'spadać', 'głupota', 'kieszeń', 'lustro', 'zając', 'szlachetny', 'wątpliwość',
        'letni', 'cyfra', 'lokalny', 'pomarańcza', 'skierować', 'poeta', 'okropny', 'istnienie', 'minister', 'umierać',
        'faza', 'dalej', 'następować', 'zrozumieć', 'dostęp', 'opuścić', 'katastrofa', 'pojemnik', 'pojawiać się',
        'ulegać', 'lekarstwo', 'przymiotnik', 'nieść', 'Chorwacja', 'inaczej', 'plama', 'policzek', 'chęć', 'królik',
        'bóstwo', 'ryzyko', 'zamiar', 'przebywać', 'radiowy', 'pałac', 'zarówno', 'nazywać się', 'paczka',
        'gospodarstwo', 'kolumna', 'graniczyć', 'biologia', 'upadek', 'wprowadzać', 'Kościół', 'rzucić', 'plus',
        'wkrótce', 'ładunek', 'sprawiedliwość', 'kolorowy', 'kapusta', 'wybory', 'uśmiech', 'zakon', 'nocny', 'kurwa',
        'Adam', 'na pewno', 'przemysłowy', 'oba', 'wyjątkowy', 'najpierw', 'futro', 'pisanie', 'planować', 'jadalny',
        'adres', 'przenosić', 'dojść', 'częściowo', 'bezpośrednio', 'wybuch', 'głodny', 'oprzeć', 'tata', 'wzgórze',
        'fizyka', 'planetoida', 'zgromadzenie', 'codzienny', 'tarcza', 'św.', 'dziennik', 'krzyczeć', 'Norwegia', '0',
        'organizować', 'urodzić się', 'wynikać', 'krawędź', 'pełnić', 'Albania', 'uciec', 'czasami', 'przekazywać',
        'praktyka', 'pokrywać', 'płot', 'oczekiwać', 'użyć', 'rządzić', 'ustawa', 'rolnik',
    )



from .. import Provider as SsnProvider


def checksum(digits):
    """
    Calculates and returns a control digit for given list of digits basing on PESEL standard.
    """
    weights_for_check_digit = [9, 7, 3, 1, 9, 7, 3, 1, 9, 7]
    check_digit = 0

    for i in range(0, 10):
        check_digit += weights_for_check_digit[i] * digits[i]

    check_digit %= 10

    return check_digit


def calculate_month(birth_date):
    """
    Calculates and returns a month number basing on PESEL standard.
    """
    year = int(birth_date.strftime('%Y'))
    month = int(birth_date.strftime('%m')) + ((int(year / 100) - 14) % 5) * 20

    return month


class Provider(SsnProvider):

    def ssn(self):
        """
        Returns 11 character Polish national identity code (Public Electronic Census System,
        Polish: Powszechny Elektroniczny System Ewidencji Ludności - PESEL).

        It has the form YYMMDDZZZXQ, where YYMMDD is the date of birth (with century
        encoded in month field), ZZZ is the personal identification number, X denotes sex
        (even for females, odd for males) and Q is a parity number.

        https://en.wikipedia.org/wiki/National_identification_number#Poland
        """
        birth_date = self.generator.date_time()

        year_without_century = int(birth_date.strftime('%y'))
        month = calculate_month(birth_date)
        day = int(birth_date.strftime('%d'))

        pesel_digits = [
            int(year_without_century / 10),
            year_without_century % 10,
            int(month / 10),
            month % 10,
            int(day / 10), day % 10,
        ]

        for _ in range(4):
            pesel_digits.append(self.random_digit())

        pesel_digits.append(checksum(pesel_digits))

        return ''.join(str(digit) for digit in pesel_digits)

    vat_id_formats = (
        'PL##########',
    )

    def vat_id(self):
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: A random Polish VAT ID
        """
        return self.bothify(self.random_element(self.vat_id_formats))



from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):

    def day_of_week(self):
        day = self.date('%w')
        DAY_NAMES = {
            "0": "सोमवार",
            "1": "मंगलवार",
            "2": "बुधवार",
            "3": "गुरुवार",
            "4": "जुम्मा",
            "5": "शनिवार",
            "6": "रविवार",
        }

        return DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        MONTH_NAMES = {
            "01": "जनवरी",
            "02": "फ़रवरी",
            "03": "मार्च",
            "04": "अप्रैल",
            "05": "मई",
            "06": "जून",
            "07": "जुलाई",
            "08": "अगस्त",
            "09": "सितंबर",
            "10": "अक्टूबर",
            "11": "नवंबर",
            "12": "दिसंबर",
        }

        return MONTH_NAMES[month]



from .. import Provider as BaseProvider

# source: https://bit.ly/32nqRv7


class Provider(BaseProvider):
    jobs = [
        "Diretor geral e gestor executivo, de empresas",
        "Diretor de vendas",
        "Diretores de investigação e desenvolvimento",
        "Diretor de produção na agricultura",
        "Diretor de produção animal",
        "Diretor de produção florestal",
        "Diretor de produção na pesca",
        "Diretor de produção na aquicultura",
        "Diretor das indústrias transformadoras",
        "Diretor das indústrias extrativas",
        "Diretor das indústrias de construção e de engenharia civil",
        "Diretor de compras",
        "Diretor de transportes",
        "Diretores de armazenagem, distribuição e relacionados",
        "Diretores dos serviços das tecnologias da informação e comunicação",
        "Diretor dos serviços de cuidados de crianças",
        "Diretor dos serviços de cuidados a pessoas idosas",
        "Diretor dos serviços de apoio social",
        "Diretor dos serviços de educação",
        "Diretor de sucursais de bancos, serviços financeiros e de seguros",
        "Oficiais e outros profissionais das forças e serviços de segurança, com funções de comando,",
        "Diretor e gerente do comércio por grosso",
        "Diretor e gerente de outros serviços, n.e.",
        "Astrónomo",
        "Oceanógrafo",
        "Botânico",
        "Farmacologista e outros especialistas relacionados",
        "Consultor de atividades das pescas",
        "Diretor geral e gestor executivo, de empresas",
        "Diretores de investigação e desenvolvimento",
        "Diretor de produção na agricultura",
        "Diretor de produção na aquicultura",
        "Diretores de armazenagem, distribuição e relacionados",
        "Diretores dos serviços das tecnologias da informação e comunicação",
        "Diretor dos serviços de cuidados de crianças",
        "Diretor dos serviços de cuidados a pessoas idosas",
        "Diretor dos serviços de apoio social",
        "Diretor dos serviços de educação",
        "Diretor de sucursais de bancos, serviços financeiros e de seguros",
        "Oficiais e outros profissionais das forças e serviços de segurança, com funções de comando,",
        "Diretor e gerente do comércio por grosso",
        "Diretor e gerente de outros serviços, n.e.",
        "Farmacologista e outros especialistas relacionados",
        "Consultor de atividades das pescas",
        "Engenheiro de construção de edifícios",
        "Engenheiro de obras de engenharia civil",
        "Engenheiro mecânico",
        "Engenheiro de minas",
        "Engenheiro metalúrgico",
        "Engenheiro eletrotécnico",
        "Engenheiro eletrónico",
        "Engenheiro de telecomunicações",
        "Designer de têxteis e moda",
        "Topógrafo",
        "Enfermeiro de cuidados gerais",
        "Enfermeiro especialista em reabilitação",
        "Enfermeiro especialista em saúde infantil e pediátrica",
        "Enfermeiro especialista em saúde mental e psiquiátrica",
        "Enfermeiro especialista em enfermagem comunitária",
        "Enfermeiro especialista em enfermagem médico cirúrgica",
        "Enfermeiro especialista em saúde materna e obstétrica",
        "Profissional paramédico",
        "Farmacêutico",
        "Fisioterapeuta",
        "Dietista e nutricionista",
        "Audiologista",
        "Terapeuta da fala",
        "Terapeuta ocupacional",
        "Professor dos ensinos básico (2.º e 3.º ciclos) e secundário",
        "Professor do ensino básico (1.º ciclo)",
        "Educador de infância",
        "Especialista em métodos de ensino",
        "Professor do ensino especial",
        "Especialista em recursos humanos",
        "Especialista em formação e desenvolvimento de recursos humanos",
        "Especialista em relações públicas",
        "Analista de sistemas",
        "Programador de software",
        "Programador Web e de multimédia",
        "Programador de aplicações",
        "Engenheiro de construção de edifícios",
        "Engenheiro de obras de engenharia civil",
        "Engenheiro de telecomunicações",
        "Enfermeiro especialista em reabilitação",
        "Enfermeiro especialista em saúde infantil e pediátrica",
        "Enfermeiro especialista em saúde mental e psiquiátrica",
        "Enfermeiro especialista em enfermagem comunitária",
        "Enfermeiro especialista em enfermagem médico cirúrgica",
        "Enfermeiro especialista em saúde materna e obstétrica",
        "Professor dos ensinos básico (2.º e 3.º ciclos) e secundário",
        "Professor do ensino básico (1.º ciclo)",
        "Especialista em métodos de ensino",
        "Especialista em recursos humanos",
        "Especialista em formação e desenvolvimento de recursos humanos",
        "Especialista em relações públicas",
        "Programador Web e de multimédia",
        "Administrador e especialista de conceção de base de dados",
        "Administrador de sistemas",
        "Especialista de redes informáticas",
        "Notário",
        "Curador de museus",
        "Bibliotecários e outros especialistas de informação relacionados",
        "Sociólogo",
        "Antropólogo",
        "Filósofo",
        "Psicólogo",
        "Especialista do trabalho social",
        "Ministro de culto",
        "Filólogo",
        "Tradutor",
        "Intérprete e outros linguistas",
        "Escultor",
        "Caricaturista",
        "Compositor",
        "Músico",
        "Coreógrafo",
        "Diretor de fotografia e de som, montador e relacionados",
        "Ator",
        "Disc Jockey",
        "Técnico de engenharia civil",
        "Técnico de eletricidade",
        "Técnico de eletrónica",
        "Técnico de inspeção de veículos",
        "Técnico da metalurgia de base e da indústria extrativa",
        "Desenhadores e técnicos afins",
        "Técnico de gás",
        "Encarregado da indústria extrativa",
        "Encarregados das indústrias da madeira e cortiça",
        "Encarregados das indústrias da pasta, papel, impressão",
        "Encarregados das indústrias refinarias de petróleo",
        "Encarregados das indústrias da transformação de minerais não metálicos",
        "Administrador e especialista de conceção de base de dados",
        "Especialista de redes informáticas",
        "Bibliotecários e outros especialistas de informação relacionados",
        "Diretor de fotografia e de som, montador e relacionados",
        "Técnico da metalurgia de base e da indústria extrativa",
        "Encarregado da indústria extrativa",
        "Encarregados das indústrias da madeira e cortiça",
        "Encarregados das indústrias da pasta, papel, impressão",
        "Encarregados das indústrias da transformação de minerais não metálicos",
        "Encarregado da construção",
        "Técnico de operação de instalações de produção de energia",
        "Técnico de operação de incineradores",
        "Técnico de operação de instalações de tratamento de água",
        "Técnico de controlo de instalações da indústria química",
        "Técnico de operação de instalações de refinação de petróleo e gás natural",
        "Técnico de controlo de instalações de produção de metais",
        "Técnico das ciências da vida (excetos ciências médicas)",
        "Técnico florestal (inclui cinegético)",
        "Oficial maquinista de navios",
        "Oficial de convés e piloto de navios",
        "Piloto de aeronaves",
        "Controlador de tráfego aéreo",
        "Técnico de cardiopneumografia",
        "Técnico de medicina nuclear",
        "Técnico de radioterapia",
        "Técnico de análises clínicas",
        "Técnico de anatomia patológica, citológica e tanatológica",
        "Auxiliar de enfermagem",
        "Parteira",
        "Profissionais de nível intermédio da medicina tradicional e complementar",
        "Terapeuta e assistente dentário",
        "Técnico de registos médicos e de informação sobre saúde",
        "Técnico dos serviços de saúde comun",
        "Técnico e assistente, de fisioterapia",
        "Assistente de médicos",
        "Pessoal de ambulâncias",
        "Corretor de bolsa, cambista",
        "Representante comercial",
        "Corretor comercial",
        "Despachante, transitário",
        "Organizador de conferências e eventos",
        "Encarregado de armazém",
        "Fiscal e encarregado de portagem",
        "Supervisor de cargas e descargas",
        "Secretário da área jurídica",
        "Secretário administrativo e executivo",
        "Encarregados das indústrias metalúrgicas de base e fabrico de produtos metálicos",
        "Técnico de operação de instalações de produção de energia",
        "Técnico de operação de incineradores",
        "Técnico de operação de instalações de tratamento de água",
        "Técnico de controlo de instalações da indústria química",
        "Técnico de operação de instalações de refinação de petróleo e gás natural",
        "Técnico de controlo de instalações de produção de metais",
        "Técnico das ciências da vida (excetos ciências médicas)",
        "Técnico florestal (inclui cinegético)",
        "Técnico de anatomia patológica, citológica e tanatológica",
        "Profissionais de nível intermédio da medicina tradicional e complementar",
        "Técnico de registos médicos e de informação sobre saúde",
        "Técnico dos serviços de saúde comunitária",
        "Técnico e assistente, de fisioterapia",
        "Corretor de bolsa, cambista",
        "Despachante, transitário",
        "Organizador de conferências e eventos",
        "Fiscal e encarregado de portagem",
        "Supervisor de cargas e descargas",
        "Secretário administrativo e executivo",
        "Secretário da área da medicina",
        "Técnico de nível intermédio dos serviços jurídicos e relacionados",
        "Técnico de nível intermédio de apoio social",
        "Jogador profissional de futebol",
        "Ciclista profissional",
        "Treinador de desportos",
        "Árbitro (juiz) de desportos",
        "Fotógrafo",
        "Técnicos de galerias, bibliotecas, arquivos e museus",
        "Toureiro, cavaleiro tauromáquico e outros profissionais similares",
        "Técnico operador das tecnologias de informação e comunicação (TIC)",
        "Técnico de apoio aos utilizadores das TIC",
        "Técnico em redes e sistemas de computadores",
        "Técnico da Web",
        "Técnico de emissões de rádio",
        "Técnico de emissões de televisão",
        "Técnico de gravação audiovisual",
        "Técnico de sistemas de comunicações via rádio",
        "Técnico de telecomunicações",
        "Empregado de escritório em geral",
        "Técnico de secretariado",
        "Empregado de banca nos casinos e outros empregados de apostas",
        "Penhorista e prestamista",
        "Empregado das agências de viagem",
        "Pessoal de informação administrativa",
        "Rececionista, exceto de hotel",
        "Outro pessoal de receção e de informação a clientes",
        "Operador de contabilidade e escrituração comercial",
        "Operador de dados de processamento de pagamentos",
        "Empregado de aprovisionamento",
        "Empregado de armazém",
        "Controlador de transportes terrestres de passageiros",
        "Controlador de transportes terrestres de mercadorias",
        "Empregado de biblioteca",
        "Carteiro",
        "Codificador, revisor de provas",
        "Escrivão",
        "Empregado de serviço de pessoal",
        "Outro pessoal de apoio de tipo administrativo, n.e.",
        "Técnico de nível intermédio dos serviços jurídicos e relacionados",
        "Técnico de nível intermédio de apoio social",
        "Técnicos de galerias, bibliotecas, arquivos e museus",
        "Toureiro, cavaleiro tauromáquico e outros profissionais similares",
        "Técnico operador das tecnologias de informação e comunicação (TIC)",
        "Técnico de apoio aos utilizadores das TIC",
        "Técnico de emissões de televisão",
        "Técnico de sistemas de comunicações via rádio",
        "Empregado de escritório em geral",
        "Empregado de banca nos casinos e outros empregados de apostas",
        "Empregado das agências de viagem",
        "Pessoal de informação administrativa",
        "Outro pessoal de receção e de informação a clientes",
        "Operador de contabilidade e escrituração comercial",
        "Operador de dados de processamento de pagamentos",
        "Empregado de aprovisionamento",
        "Controlador de transportes terrestres de passageiros",
        "Controlador de transportes terrestres de mercadorias",
        "Codificador, revisor de provas",
        "Empregado de serviço de pessoal",
        "Outro pessoal de apoio de tipo administrativo, n.e.",
        "Fiscal e cobrador de transportes públicos",
        "Cozinheiro",
        "Cabeleireiro e barbeiro",
        "Esteticista",
        "Massagista de estética",
        "Manicura, pedicura e calista",
        "Governante doméstico",
        "Pessoal de companhia e ajudantes de quarto",
        "Agente funerário",
        "Embalsamador",
        "Instrutor de condução",
        "Vendedor ambulante de produtos alimentares",
        "Vendedor em loja (estabelecimento)",
        "Operador de caixa",
        "Vendedor ao domicílio",
        "Assistente de venda de alimentos ao balcão",
        "Auxiliar de cuidados de crianças",
        "Auxiliar de professor",
        "Auxiliar de saúde",
        "Ajudante familiar",
        "Bombeiro",
        "Porteiro de hotelaria",
        "Segurança (vigilante privado), outros porteiros",
        "Outro pessoal dos serviços de proteção e segurança",
        "Agricultor e trabalhador qualificado de cereais e outras culturas extensivas",
        "Trabalhador qualificado da jardinagem",
        "Produtor e trabalhador qualificado na produção de bovinos",
        "Produtor e trabalhador qualificado na produção de ovinos e caprinos",
        "Produtor e trabalhador qualificado na produção de suínos",
        "Produtor e trabalhador qualificado na produção de outros animais de carne",
        "Avicultor e trabalhador qualificado da avicultura",
        "Sericicultor e trabalhador qualificado da sericicultura",
        "Motosserrista",
        "Sapador florestal",
        "Fiscal e cobrador de transportes públicos",
        "Encarregado de limpeza e de trabalhos domésticos em escritórios, hotéis e outros",
        "Pessoal de companhia e ajudantes de quarto",
        "Vendedor ambulante de produtos alimentares",
        "Vendedor em loja (estabelecimento)",
        "Assistente de venda de alimentos ao balcão",
        "Segurança (vigilante privado), outros porteiros",
        "Outro pessoal dos serviços de proteção e segurança",
        "Agricultor e trabalhador qualificado de cereais e outras culturas extensivas",
        "Trabalhador qualificado da jardinagem",
        "Produtor e trabalhador qualificado na produção de bovinos",
        "Produtor e trabalhador qualificado na produção de ovinos e caprinos",
        "Produtor e trabalhador qualificado na produção de suínos",
        "Produtor e trabalhador qualificado na produção de outros animais de carne",
        "Sericicultor e trabalhador qualificado da sericicultura",
        "Aquicultor (aquacultor)",
        "Pescador de águas interiores ",
        "Construtor de casas rudimentares",
        "Pedreiro",
        "Calceteiro",
        "Assentador de refratários",
        "Polidor da pedra",
        "Canteiro",
        "Cimenteiro",
        "Armador de ferro",
        "Montador de alvenarias e de pré",
        "Carpinteiro de limpos e de tosco",
        "Carpinteiro naval",
        "Montador de andaimes",
        "Espalhador de betuminosos",
        "Colocador de telhados e de coberturas",
        "Assentador de tacos e afagador de madeira",
        "Ladrilhador",
        "Estucador",
        "Trabalhador qualificado em isolamentos acústicos e térmicos",
        "Vidraceiro",
        "Canalizador",
        "Montador de tubagens",
        "Instalador de ar condicionado e de sistemas de refrigeração",
        "Pintor de construções",
        "Colocador de papel de parede, pintor decorador",
        "Pintor à pistola de superfícies",
        "Construtor de casas rudimentares",
        "Colocador de telhados e de coberturas",
        "Assentador de tacos e afagador de madeira",
        "Trabalhador qualificado em isolamentos acústicos e térmicos",
        "Instalador de ar condicionado e de sistemas de refrigeração",
        "Colocador de papel de parede, pintor decorador",
        "Envernizador",
        "Limpador de chaminés e de outras estruturas de edifícios",
        "Operador de fundição",
        "Trabalhador de corte a oxigas",
        "Bate chapa de veículos automóveis",
        "Funileiro e caldeireiro",
        "Serralheiro civil",
        "Outro preparador e montador de estruturas metálicas",
        "Forjador e ferreiro",
        "Operador de prensa de forjar, estampador",
        "Serralheiro de moldes, cunhos, cortantes",
        "Regulador e operador de máquinas ferramentas convencionais para trabalhar metais",
        "Regulador e operador de máquinas ferramentas de comando numérico computorizado",
        "Retificador de rodas, polidor e afiador de metais",
        "Mecânico e reparador de veículos automóveis",
        "Técnico de manutenção e reparação de motores de avião",
        "Mecânico e reparador, de máquinas agrícolas e industriais",
        "Reparador de bicicletas",
        "Trabalhador qualificado do fabrico e reparação de instrumentos de precisão",
        "Trabalhador qualificado do fabrico e afinação de instrumentos musicais",
        "Joalheiro",
        "Filigranista",
        "Soprador de artigos de vidro",
        "Cortador de vidro",
        "Polidor e acabador de artigos de vidro",
        "Lapidador e gravador, de vidro, cerâmica e outros materiais",
        "Pintor decorador de vidro, cerâmica e outros materiais",
        "Artesão de artigos em madeira",
        "Artesão de rendas, bordados e tapeçarias, manuais",
        "Artesão de artigos de couro",
        "Operador de pré-impressão",
        "Eletricista de construções",
        "Instalador de sistemas solares térmicos",
        "Instalador de sistemas solares fotovoltaicos",
        "Instalador de sistemas de bioenergia",
        "Limpador de chaminés e de outras estruturas de edifícios",
        "Bate chapa de veículos automóveis",
        "Outro preparador e montador de estruturas metálicas",
        "Operador de prensa de forjar, estampador",
        "Serralheiro de moldes, cunhos, cortantes",
        "Regulador e operador de máquinas ferramentas convencionais para trabalhar metais",
        "Retificador de rodas, polidor e afiador de metais",
        "Mecânico e reparador de veículos automóveis",
        "Técnico de manutenção e reparação de motores de avião",
        "Mecânico e reparador, de máquinas agrícolas e industriais",
        "Reparador de bicicletas",
        "Trabalhador qualificado do fabrico e reparação de instrumentos de precisão",
        "Polidor e acabador de artigos de vidro",
        "Lapidador e gravador, de vidro, cerâmica e outros materiais",
        "Pintor decorador de vidro, cerâmica e outros materiais",
        "Artesão de rendas, bordados e tapeçarias, manuais",
        "Eletricista de construções",
        "Instalador de sistemas solares térmicos",
        "Instalador de sistemas solares fotovoltaicos",
        "Eletromecânico, eletricista e outros instaladores de máquinas e equipamentos elétricos",
        "Instalador e reparador de linhas elétricas",
        "Mecânico e reparador de equipamentos eletrónicos",
        "Instalador e reparador, de tecnologias de informação e comunicação",
        "Cortador de carne",
        "Salsicheiro",
        "Preparador e conservador de peixe",
        "Padeiro",
        "Confeiteiro",
        "Trabalhador do fabrico de produtos lácteos",
        "Conserveiro de frutas, legumes",
        "Trabalhador do tratamento da madeira",
        "Marceneiro",
        "Tanoeiro, embutidor e outros similares a marceneiro",
        "Operador de máquinas e de equipamentos para trabalhar madeira",
        "Alfaiate e costureiro",
        "Peleiro",
        "Chapeleiro",
        "Riscador de moldes e cortador de tecidos",
        "Bordador",
        "Trabalhador de costura",
        "Estofador",
        "Curtidor de peles",
        "Maleiro",
        "Correeiro",
        "Mergulhador",
        "Carregador de fogo e dinamitador",
        "Fumigador e outros controladores, de pragas e ervas daninhas",
        "Salineiro",
        "Trabalhador de fabrico de foguetes (fogueteiro)",
        "Mineiro",
        "Trabalhador das pedreiras",
        "Operador de instalações de processamento de minérios",
        "Operador de instalações de processamento de rochas",
        "Perfurador de poços, sondador",
        "Operador de máquinas para trabalhar o cimento",
        "Operador de máquinas para trabalhar a pedra",
        "Operador de máquinas para trabalhar outros minerais",
        "Operador de instalações de fornos e de primeira transformação de metais",
        "Operador de instalações de fornos de segunda fusão, vazadores e laminadores de metais.",
        "Operador de instalações de tratamento térmico de metais",
        "Eletromecânico, eletricista e outros instaladores de máquinas e equipamentos elétricos",
        "Instalador e reparador de linhas elétricas",
        "Mecânico e reparador de equipamentos eletrónicos",
        "Instalador e reparador, de tecnologias de informação e comunicação",
        "Preparador e conservador de peixe",
        "Trabalhador do fabrico de produtos lácteos",
        "Conserveiro de frutas, legumes",
        "Trabalhador do tratamento da madeira",
        "Tanoeiro, embutidor e outros similares a marceneiro",
        "Operador de máquinas e de equipamentos para trabalhar madeira",
        "Riscador de moldes e cortador de tecidos",
        "Trabalhador de costura",
        "Carregador de fogo e dinamitador",
        "Fumigador e outros controladores, de pragas e ervas daninhas",
        "Trabalhador de fabrico de foguetes (fogueteiro)",
        "Operador de instalações de processamento de minérios",
        "Operador de instalações de processamento de rochas",
        "Perfurador de poços, sondador",
        "Operador de máquinas para trabalhar o cimento",
        "Operador de máquinas para trabalhar a pedra",
        "Operador de máquinas para trabalhar outros minerais",
        "Operador de instalações de fornos e de primeira transformação de metais",
        "Operador de instalações de fornos de segunda fusão, vazadores e laminadores de metais.",
        "Operador de instalações de tratamento térmico de metais",
        "Operador de instalações de trefilagem e estiragem",
        "Operador de máquinas de revestimento, metalização e acabamento de metais",
        "Operador de instalações e máquinas para moagem de substâncias químicas",
        "Operador de instalações e máquinas para tratamento térmico de produtos químicos",
        "Operador de instalações e máquinas,",
        "Operador de instalações e máquinas, para reação e verificação de produtos químicos",
        "Operador de instalações e máquinas, para petróleo e gás",
        "Operador de instalações e máquinas para outros tratamentos químicos",
        "Operador de máquinas para o fabrico de produtos de borracha",
        "Operador de máquinas para o fabrico de produtos de matérias plásticas",
        "Operador de máquinas para o fabrico de produtos de papel",
        "Operador de máquinas de tecer e tricotar",
        "Operador de máquinas de costura",
        "Operador de máquinas de branquear, tingir e limpar, tecidos e outros têxteis",
        "Operador de máquinas de fabrico de calçado",
        "Operador de máquinas de lavandaria",
        "Operador de máquinas de preparação de carne e peixe",
        "Operador de máquinas de moagem de cereais, de transformação de arroz e de fabricação de",
        "Operador de máquinas de produção e refinação de açúcar",
        "Operador de máquinas para preparação de chá, café e cacau",
        "Operador de máquinas para preparação de vinhos e outras bebidas",
        "Operador de máquinas para o fabrico do tabaco",
        "Operador de instalações para o fabrico de pasta de papel e de papel",
        "Operador de instalações para o trabalho da madeira e cortiça",
        "Operador de instalações para o fabrico de vidro",
        "Operador de máquinas a vapor e caldeiras",
        "Operador de máquinas para fabrico de produtos de arame",
        "Montador de maquinaria mecânica",
        "Maquinista de locomotivas",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Condutor de motociclos",
        "Motorista de táxis",
        "Motorista de automóveis ligeiros e carrinhas",
        "Motorista de autocarros",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Motorista de veículos pesados de mercadorias",
        "Operador de máquinas agrícolas e florestais, móveis",
        "Operador de máquinas de escavação, terraplenagem",
        "Operador de gruas, guindastes",
        "Operador de instalações de trefilagem e estiragem",
        "Operador de máquinas de revestimento, metalização e acabamento de metais",
        "Operador de instalações e máquinas para moagem de substâncias químicas",
        "Operador de instalações e máquinas para tratamento térmico de produtos químicos",
        "Operador de instalações e máquinas, para filtragem e separação química",
        "Operador de instalações e máquinas, para reação e verificação de produtos químicos",
        "Operador de instalações e máquinas, para petróleo e gás",
        "Operador de instalações e máquinas para outros tratamentos químicos",
        "Operador de máquinas para o fabrico de produtos de borracha",
        "Operador de máquinas para o fabrico de produtos de matérias plásticas",
        "Operador de máquinas de tecer e tricotar",
        "Operador de máquinas de costura",
        "Operador de máquinas de branquear, tingir e limpar, tecidos e outros têxteis",
        "Operador de máquinas de fabrico de calçado",
        "Operador de máquinas de lavandaria",
        "Operador de máquinas de preparação de carne e peixe",
        "Operador de máquinas de moagem de cereais, de transformação de arroz e de fabricação de",
        "Operador de máquinas de produção e refinação de açúcar",
        "Operador de máquinas para preparação de chá, café e cacau",
        "Operador de máquinas para preparação de vinhos e outras bebidas",
        "Operador de máquinas para o fabrico do tabaco",
        "Operador de instalações para o fabrico de pasta de papel e de papel",
        "Operador de instalações para o trabalho da madeira e cortiça",
        "Operador de instalações para o fabrico de vidro",
        "Operador de máquinas a vapor e caldeiras",
        "Operador de máquinas para fabrico de produtos de arame",
        "Montador de maquinaria mecânica",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Motorista de automóveis ligeiros e carrinhas",
        "Guarda freios, agulheiro e agente de manobras de caminhos de ferro",
        "Motorista de veículos pesados de mercadorias",
        "Operador de máquinas de escavação, terraplenagem",
        "Operador de gruas, guindastes",
        "Tripulação de convés de navios",
        "Trabalhador de limpeza em escritórios, hotéis",
        "Lavadeiro e engomador de roupa",
        "Lavador de veículos",
        "Lavador de janelas",
        "Trabalhador não qualificado da floresta",
        "Trabalhador não qualificado das minas",
        "Trabalhador não qualificado das pedreiras",
        "Trabalhador não qualificado de engenharia civil",
        "Trabalhador não qualificado da construção de edifícios",
        "Embalador manual da indústria transformadora",
        "Condutor de veículos acionados à mão ou ao pé",
        "Condutor de veículos de tração animal",
        "Carregadores e descarregadores não qualificados de mercadorias",
        "Preparador de refeições rápidas",
        "Ajudante de cozinha",
        "Prestador de serviços na rua",
        "Vendedor ambulante",
        "Trabalhador da recolha de resíduos",
        "Trabalhador da triagem de resíduos",
        "Cantoneiro de limpeza",
        "Empregado de lavabos",
        "Estafeta",
        "Bagageiro",
        "Distribuidor de mercadorias",
        "Colocador de anúncios",
        "Leitor de contadores",
        "Coletor de dinheiro em máquinas de venda automática",
        "Coveiro",
    ]



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = (
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}-{{last_name}}',
    )

    formats_male = (
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}-{{last_name}}',
    )

    formats = formats_male + formats_female

    # source:
    # http://www.bfs.admin.ch/bfs/portal/fr/index/news/publikationen.html?publicationID=6704
    first_names_male = [
        'Alain',
        'Albert',
        'Alexandre',
        'André',
        'Antonio',
        'Arthur',
        'Bernard',
        'Bruno',
        'Charles',
        'Christian',
        'Christophe',
        'Claude',
        'Daniel',
        'David',
        'Eric',
        'Ethan',
        'Florian',
        'François',
        'Frédéric',
        'Gabriel',
        'Georges',
        'Gilbert',
        'Guillaume',
        'Gérard',
        'Henri',
        'Hugo',
        'Jacques',
        'Jean',
        'Jean-Claude',
        'Jean-Pierre',
        'Jonathan',
        'José',
        'Julien',
        'Kevin',
        'Laurent',
        'Louis',
        'Loïc',
        'Luca',
        'Lucas',
        'Léo',
        'Manuel',
        'Marcel',
        'Mathieu',
        'Matteo',
        'Maurice',
        'Maxime',
        'Michael',
        'Michel',
        'Nathan',
        'Nicolas',
        'Noah',
        'Nolan',
        'Olivier',
        'Pascal',
        'Patrick',
        'Paul',
        'Philippe',
        'Pierre',
        'Raymond',
        'René',
        'Robert',
        'Roger',
        'Roland',
        'Romain',
        'Samuel',
        'Stéphane',
        'Sébastien',
        'Thierry',
        'Thomas',
        'Théo',
        'Vincent']

    first_names_female = [
        'Alice',
        'Alicia',
        'Ana',
        'Anna',
        'Anne',
        'Aurélie',
        'Camille',
        'Caroline',
        'Catherine',
        'Chantal',
        'Charlotte',
        'Chloé',
        'Christiane',
        'Christine',
        'Clara',
        'Claudine',
        'Corinne',
        'Céline',
        'Danielle',
        'Denise',
        'Eliane',
        'Elisa',
        'Elisabeth',
        'Elodie',
        'Emilie',
        'Emma',
        'Eva',
        'Fabienne',
        'Françoise',
        'Georgette',
        'Germaine',
        'Hélène',
        'Isabelle',
        'Jacqueline',
        'Jeanne',
        'Jessica',
        'Josiane',
        'Julie',
        'Laetitia',
        'Lara',
        'Laura',
        'Laurence',
        'Liliane',
        'Lisa',
        'Lucie',
        'Léa',
        'Madeleine',
        'Manon',
        'Marcelle',
        'Marguerite',
        'Maria',
        'Marianne',
        'Marie',
        'Mathilde',
        'Monique',
        'Mélanie',
        'Nathalie',
        'Nelly',
        'Nicole',
        'Odette',
        'Patricia',
        'Sandra',
        'Sandrine',
        'Sara',
        'Sarah',
        'Simone',
        'Sophie',
        'Stéphanie',
        'Suzanne',
        'Sylvie',
        'Thérèse',
        'Valérie',
        'Vanessa',
        'Véronique',
        'Yvette',
        'Yvonne',
        'Zoé']

    first_names = first_names_male + first_names_female

    # source = http://kunden.eye.ch/swissgen/rsr/index.html
    last_names = ['Aebi', 'Aeby', 'Alber', 'Babey', 'Badan', 'Badel', 'Bahon',
                  'Balmat', 'Barbey', 'Barillon', 'Barman', 'Bavaud', 'Beguin',
                  'Berberat', 'Bernasconi', 'Besançon', 'Besençon', 'Besse', 'Beuchat',
                  'Beuret', 'Beurret', 'Blanc', 'Bochud', 'Boechat', 'Boichat', 'Boillat',
                  'Bonvin', 'Bonvini', 'Botteron', 'Bourquard', 'Bourquin', 'Bouvier',
                  'Bovet', 'Brahier', 'Brandt', 'Broquet', 'Bugnon', 'Bujard', 'Béguelin',
                  'Candaux', 'Carraud', 'Carraux', 'Carron', 'Cattin', 'Chappuis',
                  'Chapuis', 'Charpié', 'Chatriand', 'Chatriant', 'Chaudet', 'Chenaux',
                  'Chevalley', 'Chevrolet', 'Chopard', 'Coigny', 'Comman', 'Comment',
                  'Comte', 'Conrad', 'Corbat', 'Corboz', 'Cornut', 'Cornuz', 'Corpataux',
                  'Cosandey', 'Cosendey', 'Cossy', 'Courvoisier', 'Cousin', 'Cretton',
                  'Crevoisier', 'Crivelli', 'Curdy', 'de Dardel', 'Deladoëy', 'Delèze',
                  'Deshusses', 'Diesbach', 'Droz', 'Dubey', 'Duroux', 'Duvanel', 'Délèze',
                  'Evéquoz', 'Fonjallaz', 'Francillon', 'Galland', 'Georges', 'Gillièron',
                  'Gilliéron', 'Godet', 'Grand', 'Grojean', 'Grosjean', 'Gubéran',
                  'Humbert', 'Isella', 'Jacot-Descombes', 'Jacot-Guillarmod', 'Joly',
                  'Jomini', 'Joye', 'Julliard', 'Maire', 'Marti', 'Martin', 'Marty',
                  'Masseron', 'Matile', 'Mayor', 'Menthonnex', 'Mercier', 'Meyer',
                  'Monnard', 'Monnet', 'Monnet', 'Monney', 'Montandon', 'Morand',
                  'Morard', 'Mottet', 'Mottiez', 'Muriset', 'Musy', 'Müller', 'Niquille',
                  'Nusslé', 'Nüsslin', 'Paccot', 'Pachoud', 'Paschoud', 'Pasquier',
                  'Peitrequin', 'Pellet', 'Piccand', 'Polla', 'Privet', 'Quartier',
                  'Rapin', 'Rappaz', 'Rapraz', 'Rey', 'Robadey', 'Robert', 'Romanens',
                  'Rosselat', 'Rosselet', 'Rossellat', 'Sandoz', 'Sansonnens', 'Saudan',
                  'Thorens', 'Théraulaz', 'Tinguely', 'Treboux', 'Uldry', 'Vallélian',
                  'Vermeil', 'Vienne', 'Vonlanthen', 'Vuille', 'Wicht',
                  ]



from .. import Provider as MiscProvider


class Provider(MiscProvider):
    """
    Provider for miscellaneous data for en_PH locale

    This class also houses all other provider methods that would have otherwise been weird to place in another provider.
    """

    gemstone_names = (
        'Agate', 'Amber', 'Amethyst', 'Aquamarine', 'Citrine', 'Diamond', 'Emerald', 'Garnet', 'Jade', 'Jasper',
        'Lapis Lazuli', 'Moonstone', 'Onyx', 'Opal', 'Peridot', 'Ruby', 'Sapphire', 'Sardonyx', 'Sunstone', 'Topaz',
        'Turquoise', 'Zircon',
    )
    mountain_names = (
        'Apo', 'Arayat', 'Atok', 'Banahaw', 'Bulusan', 'Caraballo', 'Cordillera', 'Cresta', 'Halcon', 'Hibok-Hibok',
        'Iriga', 'Kanlaon', 'Makiling', 'Malinao', 'Mariveles', 'Matumtum', 'Mayon', 'Palali', 'Palanan', 'Pao',
        'Pinatubo', 'Samat', 'Sicaba', 'Sierra Madre', 'Tabayoc',
    )
    plant_names = (
        'Acacia', 'Agoho', 'Akle', 'Anahaw', 'Anonas', 'Anubing', 'Aranga', 'Asparagus', 'Atis', 'Avocado', 'Azalea',
        'Azucena', 'Bagtikan', 'Bakawan', 'Balete', 'Balimbing', 'Banaba', 'Banuyo', 'Banyan', 'Baticulin', 'Batino',
        'Bauhinia', 'Bouganvilla', 'Caballero', 'Cabbage', 'Calantas', 'Calumpang', 'Camachile', 'Camia', 'Campanilla',
        'Carissa', 'Carrot', 'Catmon', 'Cattleya', 'Cauliflower', 'Celery', 'Champaca', 'Chico', 'Coconut', 'Cucumber',
        'Cypress', 'Dao', 'Dapdap', 'Dita', 'Duhat', 'Dungon', 'Gladiola', 'Gloriosa', 'Granada', 'Guijo', 'Gumamela',
        'Intsia', 'Ipil', 'Jacaranda', 'Jasmine', 'Kaimito', 'Kalachuchi', 'Kalamansi', 'Kamagong', 'Kamias',
        'Lanzones', 'Lawaan', 'Lily', 'Lumbayao', 'Mabolo', 'Macapuno', 'Macopa', 'Magnolia', 'Mahogany', 'Malugay',
        'Mayapis', 'Melon', 'Milflower', 'Molave', 'Mushroom', 'Mustard', 'Narra', 'Nipa', 'Oleander', 'Oliva',
        'Orchid', 'Palm', 'Pandan', 'Pepper', 'Piña', 'Raddish', 'Rosas', 'Sampaguita', 'Sampaloc', 'Santan', 'Santol',
        'Sineguelas', 'Squash', 'Supa', 'Talisay', 'Tamarind', 'Tanguile', 'Tindalo', 'Tulip', 'Yakal', 'Zinia',
    )
    space_object_names = (
        'Andromeda', 'Antares', 'Aquarius', 'Aries', 'Asteroid', 'Cancer', 'Canopus', 'Capricorn', 'Comet',
        'Constellation', 'Earth', 'Galaxy', 'Gemini', 'Hercules', 'Hydra', 'Juno', 'Jupiter', 'Leo', 'Libra', 'Mars',
        'Mercury', 'Milky Way', 'Neptune', 'Orion', 'Pisces', 'Planet', 'Pluto', 'Polaris', 'Sagittarius', 'Saturn',
        'Scorpio', 'Taurus', 'Uranus', 'Venus', 'Virgo', 'Zodiac',
    )
    random_object_names = gemstone_names + mountain_names + plant_names + space_object_names

    def gemstone_name(self):
        return self.random_element(self.gemstone_names)

    def mountain_name(self):
        return self.random_element(self.mountain_names)

    def plant_name(self):
        return self.random_element(self.plant_names)

    def space_object_name(self):
        return self.random_element(self.space_object_names)

    def random_object_name(self):
        return self.random_element(self.random_object_names)



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}} {{last_name}}',
        '{{first_name}} {{first_name}} {{last_name}}',
        '{{first_name}} {{first_name}} {{last_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{prefix}} {{first_name}} {{last_name}}',
    )

    first_names = ('Abel', 'Abelardo', 'Abigail', 'Abraham', 'Abril',
                   'Adalberto', 'Adán', 'Adela', 'Adriana',
                   'Aida', 'Alejandra', 'Agustín', 'Alberto', 'Aldonza', 'Alicia',
                   'Alta  Gracia', 'Alonso', 'Aldo', 'Alejandro', 'Alfonso', 'Alfredo',
                   'Alma', 'Alvaro', 'Amalia', 'Amanda', 'Amador', 'Amelia', 'Ana',
                   'Anabel', 'Ana Luisa', 'Ana María', 'Anel', 'Andrea', 'Andrés',
                   'Ángel', 'Ángela', 'Angélica', 'Antonia', 'Antonio', 'Araceli',
                   'Arcelia', 'Ariadna', 'Armando', 'Arturo', 'Asunción', 'Augusto',
                   'Aurora', 'Aurelio', 'Barbara', 'Beatriz', 'Berta', 'Benito',
                   'Benjamín', 'Bernardo', 'Bernabé', 'Bianca', 'Blanca',
                   'Bruno', 'Camila', 'Camilo', 'Caridad', 'Carla', 'Carlos', 'Carlota',
                   'Carmen', 'Carolina', 'Catalina', 'César', 'Cecilia', 'Celia',
                   'Citlali', 'Clara', 'Claudia', 'Claudio', 'Clemente', 'Concepción',
                   'Conchita', 'Cornelio', 'Cristian', 'Cristal',
                   'Cristina', 'Cristobal', 'Cynthia', 'Dalia', 'Daniel', 'Daniela',
                   'Darío', 'David', 'Débora', 'Delia', 'Diana', 'Diego', 'Dolores',
                   'Dulce', 'Dulce María', 'Eduardo', 'Elena', 'Elias', 'Elisa',
                   'Eloisa', 'Elsa', 'Elvia', 'Elvira', 'Eloy', 'Emilia', 'Emiliano',
                   'Emilio', 'Enrique', 'Eric', 'Ernesto', 'Esmeralda', 'Esteban',
                   'Estefanía', 'Estela', 'Esparta', 'Espartaco', 'Esperanza', 'Estela',
                   'Esther', 'Eugenia', 'Eugenio', 'Eva', 'Evelio', 'Fabiola',
                   'Federico', 'Felipe', 'Fernando', 'Felix', 'Fidel', 'Flavio',
                   'Florencia', 'Francisco', 'Francisco Javier', 'Francisca', 'Frida',
                   'Gabino', 'Gabriela', 'Gabriel', 'Genaro', 'Georgina', 'Gerardo',
                   'Gerónimo', 'Germán', 'Gilberto', 'Guillermina', 'Gloria',
                   'Gonzalo', 'Graciela', 'Gregorio', 'Guillermo',
                   'Guadalupe', 'Gustavo', 'Héctor', 'Helena', 'Hermelinda', 'Hernán',
                   'Hilda', 'Homero', 'Horacio', 'Hugo', 'Humberto', 'Ignacio', 'Ilse',
                   'Indira', 'Inés', 'Irene', 'Irma', 'Itzel', 'Isaac', 'Isabel',
                   'Isabela', 'Israel', 'Iván', 'Ivonne', 'Jacinto', 'Jacobo', 'Jaime',
                   'Javier', 'Jaqueline', 'Jerónimo', 'Jesús', 'Joaquín', 'Jonás',
                   'Jorge', 'Jorge Luis', 'Jos', 'José', 'Josefina', 'José Carlos',
                   'José Eduardo', 'José Emilio', 'José Luis', 'José Manuél',
                   'José María', 'Juan', 'Juana', 'Juan Carlos', 'Judith', 'Julia',
                   'Julio', 'Julio César', 'Laura', 'Leonardo', 'Leonel', 'Leonor',
                   'Karla', 'Karina', 'Leticia', 'Lorenzo', 'Lucas', 'Lilia', 'Liliana',
                   'Linda', 'Lorena', 'Lourdes', 'Lucía', 'Luisa', 'Luz', 'Luis',
                   'Luis Miguel', 'Luis Manuel', 'Magdalena', 'Manuel', 'Marco Antonio',
                   'Marcela', 'Marcos', 'Margarita', 'María', 'Marisela', 'Marisol',
                   'María del Carmen', 'María Cristina', 'María Elena',
                   'María Eugenia', 'María José', 'María Luisa', 'María Teresa', 'Marisol',
                   'Martha', 'Mayte', 'Mariano', 'Mariana', 'Mario', 'Martín', 'Mateo',
                   'Mauro', 'Mauricio', 'Maximiliano', 'Mercedes', 'Micaela', 'Minerva',
                   'Mitzy', 'Miguel', 'Miguel Ángel', 'Miriam', 'Modesto', 'Mónica',
                   'Nadia', 'Natalia', 'Natividad', 'Nancy', 'Nayeli', 'Nelly',
                   'Noelia', 'Noemí', 'Norma', 'Nicolás', 'Octavio', 'Ofelia', 'Olivia',
                   'Óliver', 'Olga', 'Óscar', 'Oswaldo', 'Omar', 'Pablo', 'Paola',
                   'Patricia', 'Pamela', 'Patricio', 'Pascual', 'Paulina', 'Pedro',
                   'Perla', 'Pilar', 'Porfirio', 'Rafaél', 'Ramiro', 'Ramón', 'Raúl',
                   'Raquel', 'Rebeca', 'Reina', 'Renato', 'René', 'Reynaldo',
                   'Ricardo', 'Roberto', 'Rodolfo', 'Rocío', 'Rodrigo', 'Rolando',
                   'Rosa', 'Rosalia', 'Rosario', 'Rubén', 'Rufino', 'Ruby', 'Salvador',
                   'Salma', 'Samuel', 'Sandra', 'Santiago', 'Sara', 'Sessa', 'Sergio',
                   'Serafín', 'Silvano', 'Silvia', 'Sofía', 'Socorro', 'Soledad',
                   'Sonia', 'Susana', 'Tania', 'Teresa', 'Teodoro', 'Timoteo', 'Tomás',
                   'Trinidad', 'Verónica', 'Vicente', 'Violeta', 'Uriel', 'Úrsula',
                   'Vanesa', 'Víctor', 'Victoria', 'Virginia', 'Wilfrido', 'Wendolin',
                   'Yeni', 'Yolanda', 'Yuridia', 'Zacarías', 'Zeferino', 'Zoé')

    last_names = ('Abrego', 'Abreu', 'Acevedo', 'Acosta', 'Acuña',
                  'Adame', 'Aguayo', 'Aguilar', 'Aguilera', 'Aguirre', 'Alarcón', 'Alba',
                  'Alcala', 'Alcántar', 'Alcaraz', 'Alejandro', 'Alemán', 'Alfaro',
                  'Almanza', 'Almaraz', 'Almonte', 'Alonso', 'Alonzo', 'Altamirano',
                  'Alva', 'Alvarado', 'Alvarez', 'Amador', 'Amaya', 'Anaya', 'Anguiano',
                  'Angulo', 'Aparicio', 'Apodaca', 'Aponte', 'Aragón', 'Aranda', 'Arce',
                  'Archuleta', 'Arellano', 'Arenas', 'Arevalo', 'Arguello', 'Arias',
                  'Armas', 'Armendáriz', 'Armenta', 'Arredondo', 'Arreola', 'Arriaga',
                  'Arroyo', 'Arteaga', 'Ávalos', 'Ávila', 'Avilés', 'Ayala', 'Baca',
                  'Badillo', 'Báez', 'Baeza', 'Bahena', 'Balderas', 'Ballesteros',
                  'Bañuelos', 'Barajas', 'Barela', 'Barragán', 'Barraza', 'Barrera',
                  'Barreto', 'Barrientos', 'Barrios', 'Batista', 'Becerra', 'Beltrán',
                  'Benavides', 'Benavídez', 'Benítez', 'Bermúdez', 'Bernal', 'Berríos',
                  'Bétancourt', 'Blanco', 'Bonilla', 'Borrego', 'Botello', 'Bravo',
                  'Briones', 'Briseño', 'Brito', 'Bueno', 'Burgos', 'Bustamante',
                  'Bustos', 'Caballero', 'Cabán', 'Cabrera', 'Cadena', 'Caldera',
                  'Calderón', 'Calvillo', 'Camacho', 'Camarillo', 'Campos', 'Canales',
                  'Candelaria', 'Cano', 'Cantú', 'Caraballo', 'Carbajal', 'Cardenas',
                  'Cardona', 'Carmona', 'Carranza', 'Carrasco', 'Carreón', 'Carrera',
                  'Carrero', 'Carrillo', 'Carrión', 'Carvajal', 'Casanova', 'Casares',
                  'Casárez', 'Casas', 'Casillas', 'Castañeda', 'Castellanos', 'Castillo',
                  'Castro', 'Cavazos', 'Cazares', 'Ceballos', 'Cedillo', 'Ceja',
                  'Centeno', 'Cepeda', 'Cervantes', 'Cervántez', 'Chacón', 'Chapa',
                  'Chavarría', 'Chávez', 'Cintrón', 'Cisneros', 'Collado', 'Collazo',
                  'Colón', 'Colunga', 'Concepción', 'Contreras', 'Cordero', 'Córdova',
                  'Cornejo', 'Corona', 'Coronado', 'Corral', 'Corrales', 'Correa',
                  'Cortés', 'Cortez', 'Cotto', 'Covarrubias', 'Crespo', 'Cruz', 'Cuellar',
                  'Curiel', 'Dávila', 'de Anda', 'de Jesús', 'de la Crúz', 'de la Fuente',
                  'de la Garza', 'de la O', 'de la Rosa', 'de la Torre', 'de León',
                  'Delgadillo', 'Delgado', 'del Río', 'del Valle', 'Díaz', 'Domínguez',
                  'Duarte', 'Dueñas', 'Durán', 'Echeverría', 'Elizondo', 'Enríquez',
                  'Escalante', 'Escamilla', 'Escobar', 'Escobedo', 'Esparza', 'Espinal',
                  'Espino', 'Espinosa', 'Espinoza', 'Esquibel', 'Esquivel', 'Estévez',
                  'Estrada', 'Fajardo', 'Farías', 'Feliciano', 'Fernández', 'Ferrer',
                  'Fierro', 'Figueroa', 'Flores', 'Flórez', 'Fonseca', 'Franco', 'Frías',
                  'Fuentes', 'Gaitán', 'Galarza', 'Galindo', 'Gallardo', 'Gallegos',
                  'Galván', 'Gálvez', 'Gamboa', 'Gamez', 'Gaona', 'Garay', 'García',
                  'Garibay', 'Garica', 'Garrido', 'Garza', 'Gastélum', 'Gaytán', 'Gil',
                  'Girón', 'Godínez', 'Godoy', 'Gómez', 'Gonzales', 'González', 'Gollum',
                  'Gracia', 'Granado', 'Granados', 'Griego', 'Grijalva', 'Guajardo',
                  'Guardado', 'Guerra', 'Guerrero', 'Guevara', 'Guillen', 'Gurule',
                  'Gutiérrez', 'Guzmán', 'Haro', 'Henríquez', 'Heredia', 'Hernádez',
                  'Hernandes', 'Hernández', 'Herrera', 'Hidalgo', 'Hinojosa', 'Holguín',
                  'Huerta', 'Hurtado', 'Ibarra', 'Iglesias', 'Irizarry', 'Jaime',
                  'Jaimes', 'Jáquez', 'Jaramillo', 'Jasso', 'Jiménez', 'Jimínez',
                  'Juárez', 'Jurado', 'Laboy', 'Lara', 'Laureano', 'Leal', 'Lebrón',
                  'Ledesma', 'Leiva', 'Lemus', 'León', 'Lerma', 'Leyva', 'Limón',
                  'Linares', 'Lira', 'Llamas', 'Loera', 'Lomeli', 'Longoria', 'López',
                  'Lovato', 'Loya', 'Lozada', 'Lozano', 'Lucero', 'Lucio', 'Luevano',
                  'Lugo', 'Luna', 'Macías', 'Madera', 'Madrid', 'Madrigal', 'Maestas',
                  'Magaña', 'Malave', 'Maldonado', 'Manzanares', 'Mares', 'Marín',
                  'Márquez', 'Marrero', 'Marroquín', 'Martínez', 'Mascareñas', 'Mata',
                  'Mateo', 'Matías', 'Matos', 'Maya', 'Mayorga', 'Medina', 'Medrano',
                  'Mejía', 'Meléndez', 'Melgar', 'Mena', 'Menchaca', 'Méndez', 'Mendoza',
                  'Menéndez', 'Meraz', 'Mercado', 'Merino', 'Mesa', 'Meza', 'Miramontes',
                  'Miranda', 'Mireles', 'Mojica', 'Molina', 'Mondragón', 'Monroy',
                  'Montalvo', 'Montañez', 'Montaño', 'Montemayor', 'Montenegro',
                  'Montero', 'Montes', 'Montez', 'Montoya', 'Mora', 'Morales', 'Moreno',
                  'Mota', 'Moya', 'Munguía', 'Muñiz', 'Muñoz', 'Murillo', 'Muro',
                  'Nájera', 'Naranjo', 'Narváez', 'Nava', 'Navarrete', 'Navarro',
                  'Nazario', 'Negrete', 'Negrón', 'Nevárez', 'Nieto', 'Nieves', 'Niño',
                  'Noriega', 'Núñez', 'Ocampo', 'Ocasio', 'Ochoa', 'Ojeda', 'Olivares',
                  'Olivárez', 'Olivas', 'Olivera', 'Olivo', 'Olmos', 'Olvera',
                  'Ontiveros', 'Oquendo', 'Ordóñez', 'Orellana', 'Ornelas', 'Orosco',
                  'Orozco', 'Orta', 'Ortega', 'Ortiz', 'Osorio', 'Otero', 'Ozuna',
                  'Pabón', 'Pacheco', 'Padilla', 'Padrón', 'Páez', 'Palacios', 'Palomino',
                  'Palomo', 'Pantoja', 'Paredes', 'Parra', 'Partida', 'Patiño', 'Paz',
                  'Pedraza', 'Pedroza', 'Pelayo', 'Peña', 'Perales', 'Peralta', 'Perea',
                  'Peres', 'Pérez', 'Pichardo', 'Piña', 'Pineda', 'Pizarro', 'Polanco',
                  'Ponce', 'Porras', 'Portillo', 'Posada', 'Prado', 'Preciado', 'Prieto',
                  'Puente', 'Puga', 'Pulido', 'Quesada', 'Quezada', 'Quiñones',
                  'Quiñónez', 'Quintana', 'Quintanilla', 'Quintero', 'Quiroz', 'Rael',
                  'Ramírez', 'Ramón', 'Ramos', 'Rangel', 'Rascón', 'Raya', 'Razo',
                  'Regalado', 'Rendón', 'Rentería', 'Reséndez', 'Reyes', 'Reyna',
                  'Reynoso', 'Rico', 'Rincón', 'Riojas', 'Ríos', 'Rivas', 'Rivera',
                  'Rivero', 'Robledo', 'Robles', 'Rocha', 'Rodarte', 'Rodrígez',
                  'Rodríguez', 'Rodríquez', 'Rojas', 'Rojo', 'Roldán', 'Rolón', 'Romero',
                  'Romo', 'Roque', 'Rosado', 'Rosales', 'Rosario', 'Rosas', 'Roybal',
                  'Rubio', 'Ruelas', 'Ruiz', 'Saavedra', 'Sáenz', 'Saiz', 'Salas',
                  'Salazar', 'Salcedo', 'Salcido', 'Saldaña', 'Saldivar', 'Salgado',
                  'Salinas', 'Samaniego', 'Sanabria', 'Sanches', 'Sánchez', 'Sandoval',
                  'Santacruz', 'Santana', 'Santiago', 'Santillán', 'Sarabia', 'Sauceda',
                  'Saucedo', 'Segovia', 'Segura', 'Sepúlveda', 'Serna', 'Serrano',
                  'Serrato', 'Sevilla', 'Sierra', 'Sisneros', 'Solano', 'Solís', 'Soliz',
                  'Solorio', 'Solorzano', 'Soria', 'Sosa', 'Sotelo', 'Soto', 'Suárez',
                  'Tafoya', 'Tamayo', 'Tamez', 'Tapia', 'Tejada', 'Tejeda', 'Téllez',
                  'Tello', 'Terán', 'Terrazas', 'Tijerina', 'Tirado', 'Toledo', 'Toro',
                  'Torres', 'Tórrez', 'Tovar', 'Trejo', 'Treviño', 'Trujillo', 'Ulibarri',
                  'Ulloa', 'Urbina', 'Ureña', 'Urías', 'Uribe', 'Urrutia', 'Vaca',
                  'Valadez', 'Valdés', 'Valdez', 'Valdivia', 'Valencia', 'Valentín',
                  'Valenzuela', 'Valladares', 'Valle', 'Vallejo', 'Valles', 'Valverde',
                  'Vanegas', 'Varela', 'Vargas', 'Vásquez', 'Vázquez', 'Vega', 'Vela',
                  'Velasco', 'Velásquez', 'Velázquez', 'Vélez', 'Véliz', 'Venegas',
                  'Vera', 'Verdugo', 'Verduzco', 'Vergara', 'Viera', 'Vigil', 'Villa',
                  'Villagómez', 'Villalobos', 'Villalpando', 'Villanueva', 'Villareal',
                  'Villarreal', 'Villaseñor', 'Villegas', 'Yáñez', 'Ybarra', 'Zambrano',
                  'Zamora', 'Zamudio', 'Zapata', 'Zaragoza', 'Zarate', 'Zavala', 'Zayas',
                  'Zedillo', 'Zelaya', 'Zepeda', 'Zúñiga')

    prefixes = ('Sr(a).', 'Dr.', 'Mtro.', 'Lic.',
                'Ing.')
